function updateCLOs() {
    const eloSelect = document.getElementById('elo');
    const cloSelect = document.getElementById('clo');

    // Clear existing CLO options
    cloSelect.innerHTML = '';

    // Create CLO options based on selected ELO
    let startCLO;
    switch (eloSelect.value) {
        case 'A':
            startCLO = 10;
            break;
        case 'B':
            startCLO = 20;
            break;
        case 'C':
            startCLO = 30;
            break;
        case 'D':
            startCLO = 40;
            break;
        case 'E':
            startCLO = 50;
            break;
        default:
            return; // Exit if no valid ELO is selected
    }

    for (let i = 0; i < 10; i++) {
        const cloNum = startCLO + i; // Calculates CLO number based on ELO
        const cloValue = 'CLO' + String(cloNum).padStart(3, '0'); // Format CLO
        const option = document.createElement('option');
        option.value = cloValue;
        option.textContent = cloValue;
        cloSelect.appendChild(option);
    }
}

let globalCount = 1; // Initialize globalCount

    document.addEventListener('DOMContentLoaded', () => {
        const submitButton = document.getElementById('submitBtn');
        const autoGenBox = document.getElementById('autoGenBox');
        const cloDropdown = document.getElementById('clo');

        // Listen for CLO selection (dropdown change)
        cloDropdown.addEventListener('change', () => {
            const selectedCLO = cloDropdown.value;
            if (selectedCLO) {
                // Show the generated value in autoGenBox (globalCount is not incremented here)
                autoGenBox.value = `SUB-${selectedCLO}-${formatCount(globalCount)}`;
            }
        });

        // Listen for submit button clicks
        submitButton.addEventListener('click', () => {
            const selectedCLO = cloDropdown.value;
            if (selectedCLO) {
                globalCount++; // Increment globalCount by 1
                autoGenBox.value = `SUB-${selectedCLO}-${formatCount(globalCount)}`; // Update display with the new count
            }
        });
    });

// Function to format the count with leading zero
function formatCount(count) {
    return count < 10 ? '0' + count : count; // Add leading zero if count is less than 10
}

document.getElementById('clo').addEventListener('change', function() {
    var clo = this.value;
    var terms = document.querySelector('input[name="terms"]').value;
    var course = document.querySelector('input[name="course"]').value;

    if (clo) {
        // Make AJAX call to fetch the most recent Sub-CLO from the database
        var xhr = new XMLHttpRequest();
        xhr.open("POST", "fetch_sub_clo.php", true); // 'fetch_sub_clo.php' will handle the database query
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        xhr.onreadystatechange = function() {
            if (xhr.readyState === 4 && xhr.status === 200) {
                var response = xhr.responseText;
                var newSubCLO;

                if (response) {
                    // If there's an existing Sub-CLO, increment the last 3 digits
                    var lastSubCLO = response.slice(-3); // Extract the last 3 digits
                    var incrementedSubCLO = (parseInt(lastSubCLO) + 1).toString().padStart(2, '0'); // Increment and pad with zeros
                    newSubCLO = 'SUB-CLO' + clo + '-' + incrementedSubCLO;
                } else {
                    // If no Sub-CLO exists, start from '01'
                    newSubCLO = 'SUB-CLO' + clo + '-01';
                }

                // Set the new Sub-CLO value in the auto-generated box
                document.getElementById('autoGenBox').value = newSubCLO;
            }
        };
        xhr.send("terms=" + terms + "&course=" + course + "&clo=" + clo);
    }
});





// Automatically update the Auto-Generation Box when CLO is selected
// document.getElementById('clo').addEventListener('change', function() {
//     const selectedCLO = this.value;

//     if (selectedCLO) {
//         // Keep the global count but do not increment it
//         const currentGlobalCount = parseInt(document.getElementById('autoGenBox').value.split('-')[2], 10) || 0;


//         // Generate the auto-generated box value based on selected CLO and current count
//         const autoGenValue = `SUB-${selectedCLO}-${String(currentGlobalCount).padStart(2, '0')}`;
//         document.getElementById('autoGenBox').value = autoGenValue;
//     }
// });

// Handle the form submission
// document.getElementById('submitBtn').addEventListener('click', function() {
//     const selectedCLO = document.getElementById('clo').value;

//     if (selectedCLO) {
//         // Keep the global count variable and do not increment it
//         const currentGlobalCount = parseInt(document.getElementById('autoGenBox').value.split('-')[2], 10) || 0;

//         // Update the auto-generated box value based on selected CLO and keep the count the same
//         const autoGenValue = `SUB-${selectedCLO}-${String(currentGlobalCount).padStart(2, '0')}`;

//         // Update the value in the form before submission
//         document.getElementById('autoGenBox').value = autoGenValue;
//     }

//     // Reset the ELO dropdown to base after submission
//     document.getElementById('elo').value = 'base';
// });
