document.getElementById('uploadForm').addEventListener('submit', function(e) {
    e.preventDefault(); // Mencegah submit form default
    
    const excelFile = document.getElementById('excelFile').files[0];
    if (!excelFile) {
        alert('Please upload an Excel file');
        return;
    }

    const reader = new FileReader();
    reader.onload = function(e) {
        const data = new Uint8Array(e.target.result);
        const workbook = XLSX.read(data, { type: 'array' });

        // Mengambil sheet pertama
        const sheetName = workbook.SheetNames[0];
        const worksheet = workbook.Sheets[sheetName];

        // Mengambil data dari row yang sesuai
        const rows = XLSX.utils.sheet_to_json(worksheet, { header: 1 });
        const courseCode = worksheet['B4'].v.substring(0, 5);

        const headerRowIndex = 6; // Header di row 7 (index mulai dari 0)
        const dataStartRow = headerRowIndex + 1; // Data mulai di baris setelah header
        
        const utsScores = [];
        
        for (let i = dataStartRow; i < rows.length; i++) {
            const row = rows[i];
            utsScores.push({
                nim: row[0],  // NIM
                name: row[1], // Name
                course_code: courseCode, // Course code dari B4
                q1: row[3], q2: row[4], q3: row[5], q4: row[6], q5: row[7], 
                q6: row[8], q7: row[9], q8: row[10], q9: row[11], q10: row[12] // Question 1-10
            });
        }

        // Kirim data ke PHP untuk diproses ke database
        sendDataToDatabase(utsScores);
    };

    reader.readAsArrayBuffer(excelFile);
});

function sendDataToDatabase(data) {
    fetch('../php/upload_excel.php', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify(data),
    })
    .then(response => response.json())
    .then(result => {
        if (result.status === 'success') {
            alert('Data uploaded successfully!');
        } else {
            alert('Failed to upload data: ' + result.message);
        }
    })
    .catch(error => {
        console.error('Error:', error);
    });
}
