document.getElementById('uploadExcelAssignmentLab').addEventListener('change', function (e) {
    const file = e.target.files[0]; // Get the selected file
    if (!file || !file.name.endsWith('.xlsx')) {
        alert('Please upload a valid Excel file.'); // Validate the file type
        return;
    }

    const reader = new FileReader();
    reader.onload = function (e) {
        const data = new Uint8Array(e.target.result); // Read the file as a byte array
        const workbook = XLSX.read(data, { type: 'array' }); // Parse the Excel workbook

        // Get the first worksheet from the workbook
        const firstSheet = workbook.Sheets[workbook.SheetNames[0]];
        const jsonData = XLSX.utils.sheet_to_json(firstSheet, { header: 1, defval: '' });

        // Extract the course code from Row 4, Column B (B4), using only the first 5 characters
        const courseCode = jsonData[3][1]?.substring(0, 5);
        
        // If the course code is not found, alert the user and use a default value
        if (!courseCode || courseCode.length < 5) {
            alert('Course code not found. Using "Code not found" instead.');
        }

        // Use the course code if it's valid, otherwise, use a placeholder
        const finalCourseCode = courseCode && courseCode.length === 5 ? courseCode : 'Code not found';

        // Insert the course code into each row, but in a separate column (for example, column 5 or beyond)
        for (let i = 7; i < jsonData.length; i++) {  // Start from Row 7, as per your logic
            if (jsonData[i].length > 0) {
                jsonData[i][18] = finalCourseCode; // Assuming column 5 (index 4) is free for Course_Code
                // If column 5 isn't free, adjust the index based on your actual Excel structure
            }
        }

        // Prepare the data to send to the server, including course code in each row
        const payload = { rows: jsonData };

        // Send data to the server-side PHP file using Fetch API
        fetch('upload_process_assignment_lab.php', {
            method: 'POST',  // Use POST for sending data
            headers: {
                'Content-Type': 'application/json'  // Send data as JSON
            },
            body: JSON.stringify(payload)  // Convert the data to JSON string
        })
        .then(response => response.json())  // Parse the JSON response from the server
        .then(result => {
            if (result.status === 'success') {
                alert('Data uploaded successfully!');
            } else {
                alert('Error: ' + result.message);  // Show error message if something goes wrong
            }
        })
        .catch(error => {
            console.error('Error:', error);  // Log any unexpected errors
            alert('An unexpected error occurred.');
        });
    };

    reader.readAsArrayBuffer(file);  // Read the file as an ArrayBuffer for Excel parsing
});
