document.getElementById('uploadExcelUASLab').addEventListener('change', function (e) {
    const file = e.target.files[0];
    if (!file || !file.name.endsWith('.xlsx')) {
        alert('Please upload a valid Excel file.');
        return;
    }

    const reader = new FileReader();
    reader.onload = function (e) {
        const data = new Uint8Array(e.target.result);
        const workbook = XLSX.read(data, { type: 'array' });

        // Get the first worksheet
        const firstSheet = workbook.Sheets[workbook.SheetNames[0]];
        const jsonData = XLSX.utils.sheet_to_json(firstSheet, { header: 1, defval: '' });

        // Course Code logic: take 5 characters from B4
        const courseCode = jsonData[3][1]?.substring(0, 5);
        
        // If the course code is not found, use "Code not found"
        if (!courseCode || courseCode.length < 5) {
            alert('Course code not found. Using "Code not found" instead.');
        }

        const finalCourseCode = courseCode && courseCode.length === 5 ? courseCode : 'Code not found';

        // Insert the course code into each row starting from row 7
        for (let i = 7; i < jsonData.length; i++) {
            if (jsonData[i].length > 0) {
                jsonData[i][2] = finalCourseCode; // Assuming column 2 is for Course_Code
            }
        }

        // Prepare the data to send to the server
        const payload = { rows: jsonData };

        // Send data via fetch to the server-side PHP
        fetch('upload_process_uas_lab.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify(payload)
        })
        .then(response => response.json())
        .then(result => {
            if (result.status === 'success') {
                alert('Data uploaded successfully!');
            } else {
                alert('Error: ' + result.message);
            }
        })
        .catch(error => {
            console.error('Error:', error);
            alert('An unexpected error occurred.');
        });
    };

    reader.readAsArrayBuffer(file);
});
