document.getElementById('uploadExcelUTS').addEventListener('change', function (e) {
    const file = e.target.files[0];
    if (!file || !file.name.endsWith('.xlsx')) {
        alert('Please upload a valid Excel file.');
        return;
    }

    const reader = new FileReader();
    reader.onload = function (e) {
        const data = new Uint8Array(e.target.result);
        const workbook = XLSX.read(data, { type: 'array' });

        const firstSheet = workbook.Sheets[workbook.SheetNames[0]];
        const jsonData = XLSX.utils.sheet_to_json(firstSheet, { header: 1, defval: '' });

        // Extract the course code from Row 4, Column B (B4)
        const courseCode = jsonData[3][1]?.substring(0, 5);
        const finalCourseCode = courseCode && courseCode.length === 5 ? courseCode : 'Code not found';

        // Check Row 5, Column B for "Tugas" or "Tugas (Teori)"
        const tugasCheck = jsonData[4][1]?.toLowerCase();
        if (tugasCheck !== 'ujian tengah semester' && tugasCheck !== 'uts (teori)') {
            alert('Please upload file UTS only');
            return;
        }

        // Total number of columns
        const totalColumns = jsonData[6]?.length; // Assuming headers are in row 7 (index 6)

        if (totalColumns > 13) {
            // Extract headers (row 7) and find relevant columns
            const headers = jsonData[6]; // Row 7 contains the headers
            const relevantIndexes = [];
            const regex = /(tugas|assignment|quiz)\s*(\d+)/i; // Regex to match "Tugas", "Assignment", or "Quiz" followed by a number

            headers.forEach((header, index) => {
                const match = header.match(regex);
                if (match) {
                    relevantIndexes.push({ index: index, number: parseInt(match[2], 10) }); // Store index and number
                }
            });

            // Sort relevant columns based on the extracted number
            relevantIndexes.sort((a, b) => a.number - b.number);

            // Create new sorted headers
            const sortedHeaders = [];
            let assignmentCount = 0;

            // Push non-relevant headers first
            headers.forEach((header, index) => {
                if (!header.match(regex)) {
                    sortedHeaders.push(header);
                } else {
                    // Push sorted relevant headers
                    sortedHeaders.push(headers[relevantIndexes[assignmentCount].index]);
                    assignmentCount++;
                }
            });

            // Replace the headers in jsonData
            jsonData[6] = sortedHeaders;

            // Now, sort the relevant columns in each row (starting from row 8 onward)
            for (let i = 7; i < jsonData.length; i++) {  // Start from Row 8, as per your logic
                const row = jsonData[i];
                const sortedRow = [...row]; // Copy the current row

                // Rearrange the row based on sorted relevant indexes
                assignmentCount = 0; // Reset for each row
                for (let j = 0; j < row.length; j++) {
                    const match = headers[j].match(regex);
                    if (match) {
                        sortedRow[j] = row[relevantIndexes[assignmentCount].index];
                        assignmentCount++;
                    }
                }

                // Replace the row in jsonData
                jsonData[i] = sortedRow;
            }
        }

        // Insert course code in each row
        for (let i = 7; i < jsonData.length; i++) {
            if (jsonData[i].length > 0) {
                jsonData[i][18] = finalCourseCode; // Assuming column 19 (index 18) is free for Course_Code
            }
        }

        // Prepare the data and send it to the server
        const payload = { rows: jsonData };
        

        // Send data to server
        fetch('uploads/upload_process_uts.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify(payload)
        })
        .then(response => response.json())
        .then(result => {
            if (result.status === 'success') {
                alert('Data uploaded successfully!');
            } else {
                alert('Error: ' + result.message);
            }
        })
        .catch(error => {
            console.error('Error:', error);
            alert('An unexpected error occurred.');
        });
    };

    reader.readAsArrayBuffer(file);
});





document.getElementById('uploadExcelUTSlab').addEventListener('change', function (e) {
    const file = e.target.files[0];
    if (!file || !file.name.endsWith('.xlsx')) {
        alert('Please upload a valid Excel file.');
        return;
    }

    const reader = new FileReader();
    reader.onload = function (e) {
        const data = new Uint8Array(e.target.result);
        const workbook = XLSX.read(data, { type: 'array' });

        const firstSheet = workbook.Sheets[workbook.SheetNames[0]];
        const jsonData = XLSX.utils.sheet_to_json(firstSheet, { header: 1, defval: '' });

        // Extract the course code from Row 4, Column B (B4)
        const courseCode = jsonData[3][1]?.substring(0, 5);
        const finalCourseCode = courseCode && courseCode.length === 5 ? courseCode : 'Code not found';

        // Check Row 5, Column B for "Tugas" or "Tugas (Teori)"
        const tugasCheck = jsonData[4][1]?.toLowerCase();
        if (tugasCheck !== 'uts (praktikum)') {
            alert('Please upload file UTS only');
            return;
        }

        // Total number of columns
        const totalColumns = jsonData[6]?.length; // Assuming headers are in row 7 (index 6)

        if (totalColumns > 13) {
            // Extract headers (row 7) and find relevant columns
            const headers = jsonData[6]; // Row 7 contains the headers
            const relevantIndexes = [];
            const regex = /(tugas|assignment|quiz|lab)\s*(\d+)/i; // Regex to match "Tugas", "Assignment", or "Quiz" followed by a number

            headers.forEach((header, index) => {
                const match = header.match(regex);
                if (match) {
                    relevantIndexes.push({ index: index, number: parseInt(match[2], 10) }); // Store index and number
                }
            });

            // Sort relevant columns based on the extracted number
            relevantIndexes.sort((a, b) => a.number - b.number);

            // Create new sorted headers
            const sortedHeaders = [];
            let assignmentCount = 0;

            // Push non-relevant headers first
            headers.forEach((header, index) => {
                if (!header.match(regex)) {
                    sortedHeaders.push(header);
                } else {
                    // Push sorted relevant headers
                    sortedHeaders.push(headers[relevantIndexes[assignmentCount].index]);
                    assignmentCount++;
                }
            });

            // Replace the headers in jsonData
            jsonData[6] = sortedHeaders;

            // Now, sort the relevant columns in each row (starting from row 8 onward)
            for (let i = 7; i < jsonData.length; i++) {  // Start from Row 8, as per your logic
                const row = jsonData[i];
                const sortedRow = [...row]; // Copy the current row

                // Rearrange the row based on sorted relevant indexes
                assignmentCount = 0; // Reset for each row
                for (let j = 0; j < row.length; j++) {
                    const match = headers[j].match(regex);
                    if (match) {
                        sortedRow[j] = row[relevantIndexes[assignmentCount].index];
                        assignmentCount++;
                    }
                }

                // Replace the row in jsonData
                jsonData[i] = sortedRow;
            }
        }

        // Insert course code in each row
        for (let i = 7; i < jsonData.length; i++) {
            if (jsonData[i].length > 0) {
                jsonData[i][18] = finalCourseCode; // Assuming column 19 (index 18) is free for Course_Code
            }
        }

        // Prepare the data and send it to the server
        const payload = { rows: jsonData };
        

        // Send data to server
        fetch('uploads/upload_process_uts_lab.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify(payload)
        })
        .then(response => response.json())
        .then(result => {
            if (result.status === 'success') {
                alert('Data uploaded successfully!');
            } else {
                alert('Error: ' + result.message);
            }
        })
        .catch(error => {
            console.error('Error:', error);
            alert('An unexpected error occurred.');
        });
    };

    reader.readAsArrayBuffer(file);
});