<?php
// Include basic page layout and database connection
include '../basic_page.html';  // Basic page layout
include '../database_connection.php'; // Database connection

// Establish the connection
$conn = new mysqli($servername, $username, $password, $dbname);

// Check if the connection is successful
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Set the course code as a filter
$course_code = 'IS 311';

// Queries to fetch sub_clo and type from each rubric table
$query_rubric_uts = "SELECT SUB_CLO FROM rubric_uts WHERE course = '$course_code'";
$query_rubric_uas = "SELECT SUB_CLO FROM rubric_uas WHERE course = '$course_code'";
$query_rubric_uts_lab = "SELECT SUB_CLO FROM rubric_uts_lab WHERE course = '$course_code'";
$query_rubric_uas_lab = "SELECT SUB_CLO FROM rubric_uas_lab WHERE course = '$course_code'";
$query_rubric_assignment = "SELECT SUB_CLO FROM rubric_assignment WHERE course = '$course_code'";
$query_rubric_assignment_lab = "SELECT SUB_CLO FROM rubric_assignment_lab WHERE course = '$course_code'";

// Execute the queries
$rubric_uts_result = $conn->query($query_rubric_uts);
$rubric_uas_result = $conn->query($query_rubric_uas);
$rubric_uts_lab_result = $conn->query($query_rubric_uts_lab);
$rubric_uas_lab_result = $conn->query($query_rubric_uas_lab);
$rubric_assignment_result = $conn->query($query_rubric_assignment);
$rubric_assignment_lab_result = $conn->query($query_rubric_assignment_lab);

// Array to hold ELOs, their counts, types, and Sub_CLOs
$elo_data = [];

// Function to convert number to letter
function numberToLetter($number) {
    $letters = ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z'];
    if ($number == 1) return 'A';
    if ($number == 2) return 'B';
    if ($number == 3) return 'C';
    if ($number == 4) return 'D';
    if ($number == 5) return 'E';
    if ($number == 6) return 'F';
    if ($number == 7) return 'G';
    if ($number == 8) return 'H';
    if ($number == 9) return 'I';
    if ($number == 0) return 'J';
    return '';
}

// Function to process and insert data for each rubric table
function insertData($result, &$elo_data, $type) {
    while ($row = $result->fetch_assoc()) {
        $sub_clo = $row['SUB_CLO'];
        // Extract the ELO based on the 9th character (as per your requirement)
        $elo = numberToLetter(substr($sub_clo, 8, 1));
        
        if (!isset($elo_data[$elo])) {
            $elo_data[$elo] = ['count' => 0, 'types' => [], 'sub_clos' => []];
        }
        
        // Increment the count of this ELO
        $elo_data[$elo]['count']++;
        
        // Add type to the types array (avoid duplicates)
        if (!in_array($type, $elo_data[$elo]['types'])) {
            $elo_data[$elo]['types'][] = $type;
        }

        // Add SUB_CLO to the sub_clos array (avoid duplicates)
        if (!in_array($sub_clo, $elo_data[$elo]['sub_clos'])) {
            $elo_data[$elo]['sub_clos'][] = $sub_clo;
        }
    }
}

// Populate the elo_data array with all rubric table data
insertData($rubric_uts_result, $elo_data, 'UTS');
insertData($rubric_uas_result, $elo_data, 'UAS');
insertData($rubric_uts_lab_result, $elo_data, 'UTS Lab');
insertData($rubric_uas_lab_result, $elo_data, 'UAS Lab');
insertData($rubric_assignment_result, $elo_data, 'Assignment');
insertData($rubric_assignment_lab_result, $elo_data, 'Assignment Lab');
?>

<h2>ELO Summary Table</h2>

<table id="eloTable" class="table table-striped table-bordered">
    <thead>
        <tr>
            <th>ELO</th>
            <th>Count</th>
            <th>Type</th>
            <th>Sub_CLO</th>
        </tr>
    </thead>
    <tbody>
        <?php
        // Insert data for ELO, Count, Types, and Sub_CLO (no duplication of ELO)
        foreach ($elo_data as $elo => $data) {
            echo "<tr>
                    <td>{$elo}</td>
                    <td>{$data['count']}</td>
                    <td>" . implode(', ', $data['types']) . "</td>
                    <td>" . implode(', ', $data['sub_clos']) . "</td>
                  </tr>";
        }
        ?>
    </tbody>
</table>

<?php
// Close the database connection
$conn->close();
?>

<!-- Include Bootstrap and DataTables JS -->
<script src="https://code.jquery.com/jquery-3.5.1.js"></script>
<script src="https://cdn.datatables.net/1.10.21/js/jquery.dataTables.min.js"></script>
<script src="https://cdn.datatables.net/1.10.21/js/dataTables.bootstrap4.min.js"></script>

<!-- Initialize DataTable -->
<script>
    $(document).ready(function() {
        $('#eloTable').DataTable();
    });
</script>
