<?php
include '../basic_page.html'; // Including the basic page layout
include '../database_connection.php'; // Include the database connection

// Function to generate random data for the chart and table
function generateRandomData($numStudents = 100) {
    $data = [];
    for ($i = 0; $i < $numStudents; $i++) {
        $studentData = [
            'name' => 'Student ' . ($i + 1),
            'a' => rand(1, 6),
            'b' => rand(1, 6),
            'c' => rand(1, 6),
            'd' => rand(1, 6),
            'e' => rand(1, 6),
            'f' => rand(1, 6),
            'g' => rand(1, 6),
            'h' => rand(1, 6),
            'i' => rand(1, 6),
            'j' => rand(1, 6)
        ];
        $data[] = $studentData;
    }
    return $data;
}

// Generate dummy data
$students = generateRandomData();

// Calculate the average for each ELO (columns a to j)
$averages = [];
foreach (['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j'] as $column) {
    $total = 0;
    foreach ($students as $student) {
        $total += $student[$column];
    }
    $averages[$column] = $total / count($students);
}

// Prepare the data for the spiderweb chart
$chartData = json_encode(array_values($averages));
?>

<!-- HTML Part -->
<div class="container">
    <h2 class="text-center mt-5">Expected Learning Outcomes (ELO) - Spiderweb Chart</h2>

    <!-- Spiderweb Chart (Radar Chart) -->
    <canvas id="eloChart" width="300" height="300"></canvas> <!-- Reduced chart size -->

    <h3 class="text-center mt-5">Student Data</h3>

    <!-- Table with Random Data for Students -->
    <div class="table-container">
        <table class="table">
            <thead>
                <tr>
                    <th>Name</th>
                    <th>A</th>
                    <th>B</th>
                    <th>C</th>
                    <th>D</th>
                    <th>E</th>
                    <th>F</th>
                    <th>G</th>
                    <th>H</th>
                    <th>I</th>
                    <th>J</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($students as $student): ?>
                    <tr>
                        <td><?php echo $student['name']; ?></td>
                        <td><?php echo $student['a']; ?></td>
                        <td><?php echo $student['b']; ?></td>
                        <td><?php echo $student['c']; ?></td>
                        <td><?php echo $student['d']; ?></td>
                        <td><?php echo $student['e']; ?></td>
                        <td><?php echo $student['f']; ?></td>
                        <td><?php echo $student['g']; ?></td>
                        <td><?php echo $student['h']; ?></td>
                        <td><?php echo $student['i']; ?></td>
                        <td><?php echo $student['j']; ?></td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <!-- Back Button to Go to the Previous Page -->
    <a href="javascript:history.back()">
        <button class="btn btn-secondary mt-4">Go Back</button>
    </a>
</div>

<!-- Include Chart.js for rendering the spiderweb chart -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    // Data for the radar chart
    const data = {
        labels: ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J'],
        datasets: [{
            label: 'Average ELO Scores',
            data: <?php echo $chartData; ?>,
            fill: true,
            backgroundColor: 'rgba(255, 99, 132, 0.2)',
            borderColor: 'rgba(255, 99, 132, 1)',
            pointBackgroundColor: 'rgba(255, 99, 132, 1)',
            pointBorderColor: '#fff',
            pointHoverBackgroundColor: '#fff',
            pointHoverBorderColor: 'rgba(255, 99, 132, 1)'
        }]
    };

    const config = {
        type: 'radar',
        data: data,
        options: {
            scales: {
                r: {
                    beginAtZero: true
                }
            }
        }
    };

    // Render the chart
    const eloChart = new Chart(
        document.getElementById('eloChart'),
        config
    );
</script>

<!-- Custom CSS for the table -->
<style>
    .table-container {
        margin: 0 30px; /* Apply 30px margin on both left and right */
    }
    .table {
        width: 100%;
        border-collapse: collapse;
    }
    .table th, .table td {
        padding: 10px;
        text-align: center;
        border: 1px solid #ddd;
    }
    .table th {
        background-color: #f2f2f2;
    }
</style>
