<?php
session_start();
header('Content-Type: application/json'); // Ensure JSON response

// Enable error reporting for debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include the database connection details
include '../database_connection.php';

// Initialize the connection using the variables from the included file
$conn = new mysqli($servername, $username, $password, $dbname);

// Check if the connection was successful
if ($conn->connect_error) {
    die(json_encode(['error' => 'Database connection failed: ' . $conn->connect_error]));
}

// Initialize response
$response = [];

// Check if course_ids and term are provided
if (isset($_POST['course_ids']) && isset($_POST['term'])) {
    $course_ids = $_POST['course_ids'];  // Array of course_ids
    $term = $_POST['term'];

    // Initialize a result array to keep track of the checks
    $checks = [];

    // Loop through the course_ids and check the pairs for each course
    foreach ($course_ids as $course_id) {
        
        // Pair 1: Check `uts_scores` and `rubric_uts`
        $uts_exists = checkRecordExists('uts_scores', $course_id, $term, 'Course_code');
        $rubric_uts_exists = checkRecordExists('rubric_uts', $course_id, $term, 'Course');

        // Check the first pair
        if ($uts_exists && $rubric_uts_exists) {
            $checks[$course_id]['uts_rubric_check'] = ['result' => true, 'message' => "Both records exist in 'uts_scores' and 'rubric_uts' for course_code $course_id"];
        } else {
            $checks[$course_id]['uts_rubric_check'] = ['result' => false, 'message' => getCheckMessage('uts_scores', 'rubric_uts', $uts_exists, $rubric_uts_exists, $course_id)];
        }

        // Pair 2: Check `uas_scores` and `rubric_uas`
        $uas_exists = checkRecordExists('uas_scores', $course_id, $term, 'Course_code');
        $rubric_uas_exists = checkRecordExists('rubric_uas', $course_id, $term, 'Course');

        // Check the second pair
        if ($uas_exists && $rubric_uas_exists) {
            $checks[$course_id]['uas_rubric_check'] = ['result' => true, 'message' => "Both records exist in 'uas_scores' and 'rubric_uas' for course_code $course_id"];
        } else {
            $checks[$course_id]['uas_rubric_check'] = ['result' => false, 'message' => getCheckMessage('uas_scores', 'rubric_uas', $uas_exists, $rubric_uas_exists, $course_id)];
        }

        // Pair 3: Check `assignment_scores` and `rubric_assignment`
        $assignment_exists = checkRecordExists('assignment_scores', $course_id, $term, 'Course_code');
        $rubric_assignment_exists = checkRecordExists('rubric_assignment', $course_id, $term, 'Course');

        // Check the third pair
        if ($assignment_exists && $rubric_assignment_exists) {
            $checks[$course_id]['assignment_rubric_check'] = ['result' => true, 'message' => "Both records exist in 'assignment_scores' and 'rubric_assignment' for course_code $course_id"];
        } else {
            $checks[$course_id]['assignment_rubric_check'] = ['result' => false, 'message' => getCheckMessage('assignment_scores', 'rubric_assignment', $assignment_exists, $rubric_assignment_exists, $course_id)];
        }
    }

    // Return the final results in JSON format
    echo json_encode($checks);

} else {
    echo json_encode(['error' => 'Missing course_ids or term']);
}

/**
 * Function to check if a record exists for the given table, course_id, and term.
 */
function checkRecordExists($table, $course_id, $term, $course_column) {
    global $conn;
    
    // Query to check if the record exists
    $stmt = $conn->prepare("SELECT 1 FROM $table WHERE $course_column = ? AND terms = ? LIMIT 1");
    if ($stmt === false) {
        die(json_encode(['error' => 'Failed to prepare statement'])); // Error handling
    }
    
    $stmt->bind_param("ss", $course_id, $term);
    $stmt->execute();
    $result = $stmt->get_result();
    
    return $result && $result->num_rows > 0;
}

/**
 * Function to generate the check message based on which records exist.
 */
function getCheckMessage($table1, $table2, $table1_exists, $table2_exists, $course_id) {
    $message = "";
    if ($table1_exists && !$table2_exists) {
        $message = "Record exists in '$table1' but not in '$table2' for course_code $course_id";
    } elseif (!$table1_exists && $table2_exists) {
        $message = "Record exists in '$table2' but not in '$table1' for course_code $course_id";
    } else {
        $message = "Neither '$table1' nor '$table2' have records for course_code $course_id";
    }
    return $message;
}

