<?php
// Include necessary files
include 'basic_page.html';
include 'database_connection.php';

$conn = new mysqli($servername, $username, $password, $dbname);

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Fetch unique terms
$terms = [];
$sql = "SELECT DISTINCT terms FROM terms";
$result = $conn->query($sql);

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $terms[] = $row['terms'];
    }
}

// Close the connection
$conn->close();
?>

<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
<link rel="stylesheet" href="../css/styles.css">
<link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>

<div class="container mt-5">
    <h1 class="mb-4">Select Terms</h1>
    <!-- Dropdown for Terms -->
    <div class="mb-3">
        <label for="terms" class="form-label">Select Terms</label>
        <select class="form-select" id="terms" name="terms" required>
            <option value="">Select Terms</option>
            <?php foreach ($terms as $term): ?>
                <option value="<?php echo htmlspecialchars($term); ?>">
                    <?php echo htmlspecialchars($term); ?>
                </option>
            <?php endforeach; ?>
        </select>
    </div>

    <!-- Table to display Course Names and Images -->
    <div class="mt-4">
        <h2>Course Details</h2>
        <table class="table table-bordered" id="coursesTable">
            <thead>
                <tr>
                    <th>Course Name</th>
                    <th>UTS</th>
                    <th>UAS</th>
                    <th>Assignment</th>
                    <!-- <th>Check</th> -->
                </tr>
            </thead>
            <tbody>
                <!-- Rows will be added dynamically using AJAX -->
            </tbody>
        </table>
    </div>
    <div>
	<a href="analytic/example.php">
    <button class="btn btn-primary mt-4">Calculated</button>
</a>

</div>
</div>


<script>
$(document).ready(function() {
    var resultFromServer = {}; // Define it globally here

    // When the term is changed, fetch courses for the selected term
    $('#terms').change(function() {
        var selectedTerm = $(this).val(); // Get selected term

        // Make an AJAX request to fetch courses based on the selected term
        $.ajax({
            url: 'fcourse_a.php',
            method: 'POST',
            data: { term: selectedTerm },
            dataType: 'json',
            success: function(response) {
                console.log('Courses Response:', response); // Debugging output

                if (Array.isArray(response)) {
                    // Clear existing table rows
                    var tableBody = $('#coursesTable tbody');
                    tableBody.empty();

                    // Loop through courses and create rows dynamically
                    response.forEach(function(course) {
                        var row = $('<tr>');
                        row.append('<td>' + course.course_name + '</td>');

                        // For UTS, check if the rubric exists (based on result from backend)
                        var utsIcon = '';
                        if (course.course_id in resultFromServer) {
                            utsIcon = resultFromServer[course.course_id].uts_rubric_check.result ? 
                                '<i class="fas fa-check" style="color: green; width: 30px;"></i>' : 
                                '<i class="fas fa-times" style="color: red; width: 30px;"></i>';
                        }
                        row.append('<td>' + utsIcon + '</td>');  // For UTS (checkmark or X)

                        // For UAS, check if the rubric exists (based on result from backend)
                        var uasIcon = '';
                        if (course.course_id in resultFromServer) {
                            uasIcon = resultFromServer[course.course_id].uas_rubric_check.result ? 
                                '<i class="fas fa-check" style="color: green; width: 30px;"></i>' : 
                                '<i class="fas fa-times" style="color: red; width: 30px;"></i>';
                        }
                        row.append('<td>' + uasIcon + '</td>');  // For UAS (checkmark or X)

                        // For Assignment, check if the rubric exists (based on result from backend)
                        var assignmentIcon = '';
                        if (course.course_id in resultFromServer) {
                            assignmentIcon = resultFromServer[course.course_id].assignment_rubric_check.result ? 
                                '<i class="fas fa-check" style="color: green; width: 30px;"></i>' : 
                                '<i class="fas fa-times" style="color: red; width: 30px;"></i>';
                        }
                        row.append('<td>' + assignmentIcon + '</td>');  // For Assignment (checkmark or X)

                        // row.append('<td class="check-column"></td>'); // New column for check status
                        row.data('course_id', course.course_id); // Store course_id in row
                        tableBody.append(row);
                    });

                    // Send selected term and course IDs to score_course_check.php for further checks
                    sendToScoreCourseCheck(selectedTerm);
                } else {
                    console.error("Unexpected response format", response);
                }
            },
            error: function(xhr, status, error) {
                console.error("AJAX Error: " + status + " - " + error);
            }
        });
    });

    // Function to send term and course IDs to score_course_check.php
    function sendToScoreCourseCheck(term) {
        var courseIds = [];
        $('#coursesTable tbody tr').each(function() {
            var courseId = $(this).data('course_id');
            courseIds.push(courseId); // Collect course IDs
        });

        // Send AJAX request to score_course_check.php
        $.ajax({
            url: 'analytic/score_course_check.php', // Second PHP file that checks course rubrics
            method: 'POST',
            data: {
                term: term,
                course_ids: courseIds
            },
            dataType: 'json',
            success: function(response) {
                console.log('Score Check Response:', response); // Debugging output
                resultFromServer = response; // Save the response globally for future use
                updatePageContent(response); // Update table with check results
            },
            error: function(xhr, status, error) {
                console.error("AJAX Error: " + status + " - " + error);
            }
        });
    }

    // Function to update table content with check results
    function updatePageContent(data) {
        $('#coursesTable tbody tr').each(function() {
            var row = $(this);
            var courseId = row.data('course_id');
            var checkColumn = row.find('.check-column');

            // Debugging: Log the data for the current courseId
            console.log('Updating course:', courseId, data[courseId]);

            // Check if data for the course exists
            var checkResult = data[courseId];

            if (checkResult) {
                // Check UTS
                var utsStatus = checkResult.uts_rubric_check.result ? 
                    '<i class="fas fa-check" style="color: green; width: 30px;"></i>' : 
                    '<i class="fas fa-times" style="color: red; width: 30px;"></i>';
                row.find('td:nth-child(2)').html(utsStatus);

                // Check UAS
                var uasStatus = checkResult.uas_rubric_check.result ? 
                    '<i class="fas fa-check" style="color: green; width: 30px;"></i>' : 
                    '<i class="fas fa-times" style="color: red; width: 30px;"></i>';
                row.find('td:nth-child(3)').html(uasStatus);

                // Check Assignment
                var assignmentStatus = checkResult.assignment_rubric_check.result ? 
                    '<i class="fas fa-check" style="color: green; width: 30px;"></i>' : 
                    '<i class="fas fa-times" style="color: red; width: 30px;"></i>';
                row.find('td:nth-child(4)').html(assignmentStatus);

                // Check overall
                var allChecksPass = checkResult.uts_rubric_check.result && 
                                    checkResult.uas_rubric_check.result && 
                                    checkResult.assignment_rubric_check.result;
                // var overallStatus = allChecksPass ? 
                //     '<i class="fas fa-check" style="color: green;"></i>' : 
                //     '<i class="fas fa-times" style="color: red;"></i>';
                // checkColumn.html(overallStatus);
            } else {
                // If no check result is available, display "N/A"
                checkColumn.html('N/A');
            }
        });
    }
});
</script>


