<?php
// Include the database connection details
include 'basic_page.html';
include 'database_connection.php';
$conn = new mysqli($servername, $username, $password, $dbname);

if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}


// Retrieve the posted term and course

$selectedTerm = isset($_POST['terms']) ? $_POST['terms'] : 'Unknown Term';
$selectedCourse = isset($_POST['course']) ? $_POST['course'] : 'Unknown Course';

$stmt = $conn->prepare("SELECT course_name FROM course WHERE course_code = ?");
$stmt->bind_param("s", $selectedCourse); // Binding the course code as a string
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $courseName = $row['course_name']; // Fetch the course name
} else {
    $courseName = 'Course not found'; // Handle case where no course is found
}

// Check if the lab is available in any of the specified tables
$labAvailable = false; // Initialize variable to track lab availability

// Prepare an array of tables to check
$tables = ['uas_lab_scores', 'uts_lab_scores', 'assignment_lab_scores'];

foreach ($tables as $table) {
    $stmt = $conn->prepare("SELECT COUNT(*) AS count FROM $table WHERE course_code = ?");
    $stmt->bind_param("s", $selectedCourse); // Binding the course code as a string
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result) {
        $row = $result->fetch_assoc();
        if ($row['count'] > 0) {
            $labAvailable = true; // Lab is available in at least one table
            break; // No need to check other tables
        }
    }
}

// Determine the lab availability message
$labMessage = $labAvailable ? "Lab Available" : "Lab Not Available";

?>


    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ELO Submission</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../css/styles.css">

    <!-- Header Section -->


    <!-- Display Selected Term and Course -->
    <div class="container mt-4">
        <div class="row">
            <div class="col text-left" style="background-color: white;">
            <h4 class="tccolor">Terms: <?php echo htmlspecialchars($selectedTerm); ?></h4>
            <h4 class="tccolor">Course: <?php echo htmlspecialchars($selectedCourse); ?> - <?php echo htmlspecialchars($courseName); ?></h4>
            </div>
        </div>
    </div>

    <!-- Hidden Form for Posting Terms and Course -->
    <form id="hiddenForm" method="POST" action="">
        <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerm); ?>">
        <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourse); ?>">
    </form>

    <!-- Box 1 with 2 buttons -->
    <div class="container mt-4">
        <div class="card mb-4">
            <div class="card-body text-left"> <!-- Centered text -->
                <h5 class="card-title">ELO</h5>
                <div class="mb-2">
                    <a href="../php/clo/view_clo_table.php" class="btn btn-primary" onclick="submitForm(); return false;">CLO</a>
                    <a href="../php/sub_clo/view_subclo_table.php" class="btn btn-secondary" onclick="submitForm(); return false;">SUB-CLO</a>
                </div>
            </div>
        </div>
    </div>

<!-- Box 2 with 3 buttons -->

<!-- Original Scores Box (remains unchanged) -->
<div class="container mt-4">
    <div class="card mb-4">
        <div class="card-body text-left"> <!-- Centered text -->
            <h5 class="card-title">Rubric</h5>
            <div class="mb-2">
                <a href="../php/rubric/r_uts/view_rubric_uts_table.php" class="btn btn-success" onclick="submitForm(); return false;">Rubric UTS</a>
                <a href="../php/rubric/r_uas/view_rubric_uas_table.php" class="btn btn-warning" onclick="submitForm(); return false;">Rubric UAS</a>
                <a href="../php/rubric/r_assignment/view_rubric_asg_table.php" class="btn btn-danger" onclick="submitForm(); return false;">Rubric Assignment</a>
            </div>
        </div>
    </div>

</div>
<?php if ($labAvailable): ?> <!-- Check if lab is available -->
    <div class="container mt-4">
        <div class="card mb-4">
            <div class="card-body text-left"> <!-- Centered text -->
                <h5 class="card-title">Scores Lab</h5> <!-- Changed title -->
                <div class="mb-2">
                    <a href="rubric/r_lab/r_uts/view_rubric_uts_lab_table.php" class="btn btn-success" onclick="submitForm(); return false;">Rubric UTS</a>
                    <a href="rubric/r_lab/r_uas/view_rubric_uas_lab_table.php" class="btn btn-warning" onclick="submitForm(); return false;">Rubric UAS</a>
                    <a href="rubric/r_lab/r_assignment/view_rubric_asg_lab_table.php" class="btn btn-danger" onclick="submitForm(); return false;">Rubric Assignment</a>
                </div>
            </div>
        </div>
        
    </div>
<?php endif; ?>
<div class="container mt-4"><a href="../php/terms_and_course.php" class="btn btn-secondary">Back</a></div>


    <!-- Display Selected Term, Course, and Lab Availability -->



    <script>
        function submitForm() {
            const action = event.target.getAttribute('href'); // Get the URL from the clicked button
            const form = document.getElementById('hiddenForm');
            form.action = action; // Set the form's action to the URL
            form.submit(); // Submit the form
        }
    </script>
   


    <?php
        // Close the database connection
        $conn->close();
    ?>

    <script src="../js/overlay_menu_box.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.10.2/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.min.js"></script>
