<?php
include '../database_connection.php';
include '../basic_page.html';
$conn = new mysqli($servername, $username, $password, $dbname);

// Check the connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Retrieve the posted term and course code
$selectedTerm = isset($_POST['terms']) ? $_POST['terms'] : 'Unknown Term';
$selectedCourseCode = isset($_POST['course']) ? $_POST['course'] : 'Unknown Course';

// Look up the course name in the database
$courseName = 'Unknown Course'; // Default value
if ($selectedCourseCode !== 'Unknown Course') {
    $sql = "SELECT course_name FROM course WHERE course_code = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $selectedCourseCode); // Assuming course_code is a string
    $stmt->execute();
    
    $stmt->bind_result($courseName);
    $stmt->fetch();
    $stmt->close();
}

// Retrieve data for ELO from elo_template table
$eloOptions = [];
$eloSql = "SELECT elo, elo_description FROM elo_template";
$eloStmt = $conn->prepare($eloSql);
$eloStmt->execute();
$eloStmt->bind_result($elo, $elo_description);
while ($eloStmt->fetch()) {
    $eloOptions[] = ['elo' => $elo, 'description' => $elo_description];
}
$eloStmt->close();

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['submit'])) {
    $terms = $_POST['terms'];
    $course = $_POST['course'];
    $elo = $_POST['elo'];
    $clo = $_POST['clo'];
    $description = $_POST['description'];

    // Insert into elo table
    $insertSQL = "INSERT INTO clo (Terms, Course, ELO, CLO, Description) VALUES (?, ?, ?, ?, ?)";
    $insertStmt = $conn->prepare($insertSQL);
    $insertStmt->bind_param("sssss", $terms, $course, $elo, $clo, $description);
    
    if ($insertStmt->execute()) {
        echo "<div class='alert alert-success'>Record successfully added to CLO table.</div>";
    } else {
        echo "<div class='alert alert-danger'>Error: " . $insertStmt->error . "</div>";
    }

    $insertStmt->close();
}
?>

<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
<link rel="stylesheet" href="/testing/css/styles.css">

<script>
    function updateCLOs() {
        const eloSelect = document.getElementById('elo');
        const cloSelect = document.getElementById('clo');
        const selectedELO = eloSelect.value;

        // Clear existing options
        cloSelect.innerHTML = '';

        // Add an initial 'Select CLO' option
        const defaultOption = document.createElement('option');
        defaultOption.textContent = 'Select CLO';
        defaultOption.disabled = true;
        defaultOption.selected = true;
        cloSelect.appendChild(defaultOption);

        if (selectedELO) {
            // Make an AJAX request to fetch CLO options based on selected ELO
            const xhr = new XMLHttpRequest();
            xhr.open('POST', 'fetch_clo.php', true);
            xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
            xhr.onreadystatechange = function() {
                if (xhr.readyState === 4 && xhr.status === 200) {
                    const response = JSON.parse(xhr.responseText);
                    if (response.success) {
                        response.clos.forEach(function(cloOption) {
                            const option = document.createElement('option');
                            option.value = cloOption.clo;
                            option.textContent = cloOption.clo;
                            cloSelect.appendChild(option);
                        });
                    } else {
                        alert('No CLOs found for the selected ELO.');
                    }
                }
            };
            xhr.send('elo=' + encodeURIComponent(selectedELO));
        }
    }
</script>
<script >
    function fetchCLODescription() {
    const cloSelect = document.getElementById('clo');
    const descriptionField = document.getElementById('description');
    const selectedCLO = cloSelect.value;

    if (selectedCLO) {
        // Make an AJAX request to fetch the CLO description
        const xhr = new XMLHttpRequest();
        xhr.open('POST', 'fetch_clo_desc.php', true);
        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
        xhr.onreadystatechange = function() {
            if (xhr.readyState === 4 && xhr.status === 200) {
                const response = JSON.parse(xhr.responseText);
                if (response.success) {
                    descriptionField.value = response.description;
                } else {
                    descriptionField.value = 'Description not found.';
                }
            }
        };
        xhr.send('clo=' + encodeURIComponent(selectedCLO));
    }
}

</script>

<!-- Display Selected Term and Course -->
<div class="container mt-4">
    <div class="row">
        <div class="col text-left" style="background-color: white;">
            <h4>Term: <?php echo htmlspecialchars($selectedTerm); ?></h4>
            <h4>Course: <?php echo htmlspecialchars($selectedCourseCode); ?> - <?php echo htmlspecialchars($courseName); ?></h4>
        </div>
    </div>
</div>

<!-- Go Back Button -->
<div class="container mt-4">
    <form action="view_clo_table.php" method="POST"> <!-- Updated back button href -->
        <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerm); ?>">
        <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourseCode); ?>">
        <button type="submit" class="btn btn-secondary">Go Back</button>
    </form>
</div>

<!-- ELO and CLO Dropdowns -->
<div class="container mt-4">
    <form action="<?php echo htmlspecialchars($_SERVER['PHP_SELF']); ?>" method="POST">
        <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerm); ?>">
        <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourseCode); ?>">
        
        <div class="mb-3">
            <label for="elo" class="form-label">Select ELO</label>
            <select id="elo" name="elo" class="form-select" onchange="updateCLOs()">
                <option value="" selected disabled>Select ELO</option>
                <?php
                    foreach ($eloOptions as $eloOption) {
                        echo "<option value='" . htmlspecialchars($eloOption['elo']) . "'>" . htmlspecialchars($eloOption['elo']) . "</option>";
                    }
                ?>
            </select>
        </div>

<div class="mb-3">
    <label for="clo" class="form-label">Select CLO</label>
    <select id="clo" name="clo" class="form-select" onchange="fetchCLODescription()">
        <option value="" selected disabled>Select CLO</option>
    </select>
</div>


        <div class="mb-3">
            <label for="description" class="form-label">Description</label>
            <textarea id="description" name="description" class="form-control" readonly></textarea>
        </div>


        <button type="submit" name="submit" class="btn btn-primary">Submit</button>
    </form>
    <br>
</div>

<!-- Footer Section -->
