<?php
// Include database connection
include '../database_connection.php';

$conn = new mysqli($servername, $username, $password, $dbname);

// Check the connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Fetch ELO values from elo_template table
$selectedTerm = isset($_POST['terms']) ? $_POST['terms'] : 'Unknown Term';
$selectedCourse = isset($_POST['course']) ? $_POST['course'] : 'Unknown Course';

// If session has selected terms and courses, use those values
if (isset($_SESSION['selected_terms']) && isset($_SESSION['selected_course'])) {
    $selectedTerm = $_SESSION['selected_terms'];
    $selectedCourse = $_SESSION['selected_course'];
}

// Fetch ELO from elo_template table
$sqlELO = "SELECT elo FROM elo_template";
$resultELO = $conn->query($sqlELO);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['submit'])) {
    $terms = $_POST['terms'];
    $course = $_POST['course'];
    $selectedELO = isset($_POST['elo']) ? $_POST['elo'] : null;
    $selectedCLO = isset($_POST['clo']) ? $_POST['clo'] : null;
    $selectedDescription = isset($_POST['description']) ? $_POST['description'] : '';

    if ($selectedELO && $selectedCLO && $terms != 'Unknown Term' && $course != 'Unknown Course') {
        // Insert data into the clo table
        $sqlInsert = "INSERT INTO clo (terms, course, elo, clo, description) VALUES (?, ?, ?, ?, ?)";
        $stmtInsert = $conn->prepare($sqlInsert);
        $stmtInsert->bind_param("sssss", $terms, $course, $selectedELO, $selectedCLO, $selectedDescription);

        if ($stmtInsert->execute()) {
            echo "Data inserted successfully!";
        } else {
            echo "Error: " . $stmtInsert->error;
        }

        $stmtInsert->close();
    } else {
        echo "Terms or Course cannot be 'Unknown Term' or 'Unknown Course'.";
    }
}

// Fetch CLO values based on selected ELO
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['elo'])) {
    $selectedELO = $_POST['elo'];
    $sqlCLO = "SELECT clo, clo_description FROM clo_template WHERE elo = ?";
    $stmtCLO = $conn->prepare($sqlCLO);
    $stmtCLO->bind_param("s", $selectedELO);
    $stmtCLO->execute();
    $resultCLO = $stmtCLO->get_result();
    $cloOptions = [];
    while ($row = $resultCLO->fetch_assoc()) {
        $cloOptions[] = [
            'clo' => $row['clo'],
            'clo_description' => $row['clo_description']
        ];
    }
    $stmtCLO->close();
} else {
    $cloOptions = [];
}

$courseName = 'Unknown Course'; // Default value
if ($selectedCourse !== 'Unknown Course') {
    $sql = "SELECT course_name FROM course WHERE course_code = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $selectedCourse); // Assuming course_code is a string
    $stmt->execute();
    
    $stmt->bind_result($courseName);
    $stmt->fetch();
    $stmt->close();
}

$conn->close();
include "../basic_page.html";
?>


<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css">
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>

<script>
function updateCLOs() {
    const eloSelect = document.getElementById('elo');
    const cloSelect = document.getElementById('clo');
    const selectedELO = eloSelect.value;
    cloSelect.innerHTML = '<option value="" selected disabled>Select CLO</option>';

    if (selectedELO) {
        const xhr = new XMLHttpRequest();
        xhr.open('POST', 'fetch_clo.php', true);
        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
        xhr.onload = function() {
            if (xhr.status === 200) {
                const cloOptions = JSON.parse(xhr.responseText);
                cloOptions.forEach(function(clo) {
                    const option = document.createElement('option');
                    option.value = clo.clo;
                    option.textContent = clo.clo;
                    cloSelect.appendChild(option);
                });
            }
        };
        xhr.send('elo=' + encodeURIComponent(selectedELO));
    }
}

function updateDescription() {
    const cloSelect = document.getElementById('clo');
    const descriptionBox = document.getElementById('description');
    const selectedCLO = cloSelect.value;

    if (selectedCLO) {
        const xhr = new XMLHttpRequest();
        xhr.open('POST', 'fetch_clo_desc.php', true);
        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
        xhr.onload = function() {
            if (xhr.status === 200) {
                const response = JSON.parse(xhr.responseText);
                descriptionBox.value = response.description || '';
            }
        };
        xhr.send('clo=' + encodeURIComponent(selectedCLO));
    }
}
</script>

<div class="container mt-4">
    <div class="row">
        <div class="col text-left" style="background-color: white;">
            <h4>Term: <?php echo htmlspecialchars($selectedTerm); ?></h4>
            <h4>Course: <?php echo htmlspecialchars($selectedCourse); ?> - <?php echo htmlspecialchars($courseName); ?></h4>
        </div>
    </div>
</div>

<!-- Form for ELO, CLO selection, Terms, and Course -->
<div class="container mt-4">
    <form action="<?php echo htmlspecialchars($_SERVER['PHP_SELF']); ?>" method="POST">
        <div class="mb-3">
            <label for="elo" class="form-label">Select ELO</label>
            <select id="elo" name="elo" class="form-select" onchange="updateCLOs()" required>
                <option value="" selected disabled>Select ELO</option>
                <?php
                if ($resultELO->num_rows > 0) {
                    while ($row = $resultELO->fetch_assoc()) {
                        $selected = (isset($_POST['elo']) && $_POST['elo'] === $row['elo']) ? 'selected' : '';
                        echo '<option value="' . htmlspecialchars($row['elo']) . '" ' . $selected . '>' . htmlspecialchars($row['elo']) . '</option>';
                    }
                }
                ?>
            </select>
        </div>

        <div class="mb-3">
            <label for="clo" class="form-label">Select CLO</label>
            <select id="clo" name="clo" class="form-select" onchange="updateDescription()" required>
                <option value="" selected disabled>Select CLO</option>
                <?php
                if (!empty($cloOptions)) {
                    foreach ($cloOptions as $cloOption) {
                        $selected = (isset($_POST['clo']) && $_POST['clo'] === $cloOption['clo']) ? 'selected' : '';
                        echo '<option value="' . htmlspecialchars($cloOption['clo']) . '" ' . $selected . '>' . htmlspecialchars($cloOption['clo']) . '</option>';
                    }
                }
                ?>
            </select>
        </div>

        <div class="mb-3">
            <label for="description" class="form-label">Description</label>
            <textarea id="description" name="description" class="form-control" rows="3" readonly>
                <?php echo isset($_POST['description']) ? htmlspecialchars($_POST['description']) : ''; ?>
            </textarea>
        </div>

        <button type="submit" name="submit" class="btn btn-primary">Submit</button>
    </form>
</div>

<div class="container mt-4">
    <form action="view_clo_table.php" method="POST">
        <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerm1); ?>">
        <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourse1); ?>">
        <button type="submit" class="btn btn-secondary">Go Back</button>
    </form>
</div>
