<?php
// Include the database connection details
include '../database_connection.php';
$conn = new mysqli($servername, $username, $password, $dbname);

if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Retrieve the passed data
$idClo = isset($_POST['clo_id']) ? $_POST['clo_id'] : 'Unknown ID';
$selectedCourse = isset($_POST['course']) ? $_POST['course'] : 'Unknown Course';
$selectedTerm = isset($_POST['terms']) ? $_POST['terms'] : 'Unknown Term';

// Prepare the SQL query to get details for the specific id_clo
$sql = "SELECT * FROM clo WHERE id_clo = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("s", $idClo);
$stmt->execute();
$result = $stmt->get_result();
$row = $result->fetch_assoc();

// Close the connection
$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Display CLO Details</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-4">
        <h2>CLO Details</h2>

        <div class="mb-3">
            <label for="course" class="form-label">Course:</label>
            <p id="course" class="form-control-plaintext"><?php echo htmlspecialchars($selectedCourse); ?></p>
        </div>

        <div class="mb-3">
            <label for="terms" class="form-label">Terms:</label>
            <p id="terms" class="form-control-plaintext"><?php echo htmlspecialchars($selectedTerm); ?></p>
        </div>

        <?php if ($row): ?>
            <h4>CLO Information:</h4>
            <form method="POST" action="../clo/update_clo.php">
                <div class="mb-3">
                    <label for="clo" class="form-label">CLO:</label>
                    <input type="text" name="clo" id="clo" class="form-control" value="<?php echo htmlspecialchars($row['CLO']); ?>" readonly>
                </div>

                <div class="mb-3">
                    <label for="description" class="form-label">Description:</label>
                    <textarea name="description" id="description" class="form-control"><?php echo htmlspecialchars($row['Description']); ?></textarea>
                </div>

                <input type="hidden" name="clo_id" value="<?php echo htmlspecialchars($idClo); ?>">
                <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerm); ?>">
                <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourse); ?>">
                
                <button type="submit" class="btn btn-primary mt-3">Save Changes</button>
            </form>
        <?php else: ?>
            <p>No details found for this CLO ID.</p>
        <?php endif; ?>

        <!-- Back to List form -->
        <form method="POST" action="view_clo_table.php" style="display:inline;">
            <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerm); ?>">
            <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourse); ?>">
            <button type="submit" class="btn btn-secondary mt-3">Back to List</button>
        </form>


    </div>
</body>
</html>
