<?php
session_start();
header('Content-Type: application/json'); // Ensure JSON response

// Enable error reporting for debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

include 'database_connection.php';

// Initialize response
$courses = [];

$conn = new mysqli($servername, $username, $password, $dbname);
if ($conn->connect_error) {
    die(json_encode(['error' => 'Connection failed: ' . $conn->connect_error]));
}

if (isset($_POST['term'])) {
    $term = $_POST['term'];

    // Use prepared statement to fetch course names and course_id where the 'terms' column matches the selected term
    $stmt = $conn->prepare("SELECT DISTINCT course_name, course_id FROM terms WHERE terms = ?");
    $stmt->bind_param("s", $term); // Bind the selected term to the prepared statement
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result && $result->num_rows > 0) {
        while ($row = $result->fetch_assoc()) {
            // Add course_id along with course_name to the response
            $courses[] = [
                'course_name' => $row['course_name'],
                'course_id' => $row['course_id']
            ];
        }
    }
    $stmt->close();
}

echo json_encode($courses); // Return a clean JSON response
$conn->close();
?>
