<?php
include '../database_connection.php';
$conn = new mysqli($servername, $username, $password, $dbname);

// Check the connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

$selectedTerm = isset($_POST['terms']) ? $_POST['terms'] : 'Unknown Term';
$selectedCourseCode = isset($_POST['course']) ? $_POST['course'] : 'Unknown Course';

// Initialize the count of included columns
$totalIncludedColumns = 0;

// Check if the form is submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST['submitRubric'])) {
        // Debugging check
        echo "Form submitted successfully!";
        
        // Sanitize inputs
        $selectedTerm = htmlspecialchars($selectedTerm);
        $selectedCourse = htmlspecialchars($selectedCourseCode);
        $selectedQuestion = htmlspecialchars($_POST['includedColumns']);
        $selectedSubCLO = htmlspecialchars($_POST['subCLO']);
        $rWeight = htmlspecialchars($_POST['inputA']);
        $qWeight = htmlspecialchars($_POST['inputB']);

        // Prepare the SQL statement for inserting into rubric_uts
        $stmtInsert = $conn->prepare("INSERT INTO rubric_assignment (terms, course, question, sub_clo, r_weight, q_weight) VALUES (?, ?, ?, ?, ?, ?)");
        $stmtInsert->bind_param("ssssdd", $selectedTerm, $selectedCourse, $selectedQuestion, $selectedSubCLO, $rWeight, $qWeight);
        
        if ($stmtInsert->execute()) {
            echo "<p>Data successfully inserted into rubric_assignment.</p>";
        } else {
            echo "<p>Error inserting data: " . $stmtInsert->error . "</p>";
        }

        $stmtInsert->close();
    } else {
        echo "Form not submitted!";
    }
}

// Prepare the SQL statement for UTS scores
$stmt = $conn->prepare("SELECT * FROM assignment_scores WHERE course_code = ? AND terms = ?");
$stmt->bind_param("ss", $selectedCourseCode, $selectedTerm);
$stmt->execute();
$result = $stmt->get_result();

// Get column names
$columnNames = [];
if ($result->num_rows > 0) {
    // Fetch all rows into an array
    $rows = $result->fetch_all(MYSQLI_ASSOC);
    // Get column names from the first row
    $columnNames = array_keys($rows[0]);
    
    // Iterate through each column (starting from index 4)
    for ($i = 4; $i < count($columnNames); $i++) {
        $currentColumnSum = 0; // Initialize the sum for the current column
        
        // Check each row for the current column
        foreach ($rows as $row) {
            $columnValue = $row[$columnNames[$i]];
            if (is_numeric($columnValue)) {
                $currentColumnSum += $columnValue; // Sum the values of the column
            }
        }

        // Check if the sum meets the inclusion criteria
        if ($currentColumnSum >= 1) {
            $totalIncludedColumns++; // Count this column as included
            echo "<p>Column " . ($i + 1) . " - Sum: $currentColumnSum (Included)</p>";
        } else {
            echo "<p>Column " . ($i + 1) . " - Sum: $currentColumnSum (Excluded)</p>";
        }
    }

    // Display the total counts of included and excluded columns
    echo "<h4>Total Included Columns: $totalIncludedColumns</h4>";
    echo "<h4>Total Excluded Columns: " . (count($columnNames) - $totalIncludedColumns) . "</h4>";
} else {
    echo "<p>No rows found in assignment_scores for course: " . htmlspecialchars($selectedCourse) . " and term: " . htmlspecialchars($selectedTerm) . ".</p>";
}

// Prepare the SQL statement for fetching SUB_CLO from elo table
$stmtCLO = $conn->prepare("SELECT SUB_CLO FROM elo WHERE course = ? AND terms = ?");
$stmtCLO->bind_param("ss", $selectedCourseCode, $selectedTerm);
$stmtCLO->execute();
$resultCLO = $stmtCLO->get_result();

// Fetch SUB_CLO values
$subCLOOptions = [];
if ($resultCLO->num_rows > 0) {
    while ($row = $resultCLO->fetch_assoc()) {
        $subCLOOptions[] = htmlspecialchars($row['SUB_CLO']);
    }
}

$stmtCLO->close();

// Close the database connection
$conn->close();
?>
    


<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ELO Submission</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../../css/styles.css">
    <script>
        function updateValue() {
            // Get the value from the first textbox
            const inputValue = parseFloat(document.getElementById('inputA').value) || 0;
            // Calculate 30% of the input value
            const calculatedValue = inputValue * 0.3;
            // Update the second textbox with the calculated value
            document.getElementById('inputB').value = calculatedValue.toFixed(2);
        }
    </script>
</head>
<body>
    <!-- Header Section -->
    <div class="container-fluid bg-light mb-4">
        <div class="row">
            <div class="col text-center header-container">
                <img id="menuButton" src="../../assets/menu_bar.png" alt="Menu" class="blackmagic-menu">
                <h2 class="header-title py-3">MyClass</h2>
            </div>
        </div>
    </div>
    <div id="menuOverlay" class="overlay">
        <div class="menu">
            <h3>Menu</h3>
            <ul>
                <li><a href="../php/index_dashboard.php">Dashboard</a></li>
                <li id="menuItemUpload">
                    <a href="#">Halaman<br>Upload</a> <!-- No actual link -->
                </li>
                <li><a href="../php/elo_base_page.php">View ELO</a></li>
                <li><a href="#">Item 4</a></li>
            </ul>
        </div>
    </div>

    <div id="centerBox" class="center-box">
        <div class="box-content">
            <h2>Select an Action</h2>
            <button class="btn btn-primary mb-2" id="btnLec">Upload LEC</button>
            <button class="btn btn-secondary" id="btnLab">Upload LAB</button>
        </div>
    </div>
    
    <div class="container mt-4">
        <h3>Selected Term: <?php echo htmlspecialchars($selectedTerm); ?></h3>
        <h3>Course: <?php echo htmlspecialchars($selectedCourseCode); ?></h3>

        <form method="post" action="">
            <!-- Hidden input for terms and course to retain the values -->
            <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerm); ?>">
            <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourseCode); ?>">

            <!-- Simple Dropdown for included columns -->
            <div class="mb-3">
                <label for="includedColumns" class="form-label">Select Column Option:</label>
                <select class="form-select" id="includedColumns" name="includedColumns">
                    <option value="" disabled selected>Select an option</option>
                    <?php for ($j = 1; $j <= $totalIncludedColumns; $j++): ?>
                        <option value="<?php echo $j; ?>">Assignment <?php echo $j; ?></option>
                    <?php endfor; ?>
                </select>
            </div>

            <!-- Dropdown for SUB_CLO from elo table -->
            <div class="mb-3">
                <label for="subCLO" class="form-label">Select SUB_CLO:</label>
                <select class="form-select" id="subCLO" name="subCLO">
                    <option value="" disabled selected>Select a SUB_CLO</option>
                    <?php foreach ($subCLOOptions as $subCLO): ?>
                        <option value="<?php echo $subCLO; ?>"><?php echo $subCLO; ?></option>
                    <?php endforeach; ?>
                </select>
            </div>

            <!-- Textboxes for user input and auto-calculated value -->
            <div class="mb-3">
                <div class="row">
                    <div class="col">
                        <label for="inputA" class="form-label">R. Weight:</label>
                        <input type="number" class="form-control" id="inputA" name="inputA" placeholder="Enter ITG" step="0.01" oninput="updateValue()">
                    </div>
                    <div class="col">
                        <label for="inputB" class="form-label">Q. Weight:</label>
                        <input type="text" class="form-control" id="inputB" name="inputB" placeholder="Auto Calculated" readonly>
                    </div>
                </div>
            </div>

            <!-- Submit Button -->
            <button type="submit" class="btn btn-primary" name="submitRubric">Submit</button>
        </form>

    </div>
 <div class="container mt-4">
    <form action="view_rubric_asg_table.php" method="POST"> <!-- Change to the appropriate page -->
        <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerm); ?>">
        <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourseCode); ?>">
        <button type="submit" class="btn btn-secondary">Go Back</button>
    </form>
</div>
    <script src="../js/overlay_menu_box.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.10.2/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.min.js"></script>

</body>
</body>
</html>
