<?php
    include '../database_connection.php';
    $conn = new mysqli($servername, $username, $password, $dbname);

    // Check the connection
    if ($conn->connect_error) {
        die("Connection failed: " . $conn->connect_error);
    }

    // Check if a delete request has been made
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_id'])) {
        $deleteId = $_POST['delete_id'];
        $deleteStmt = $conn->prepare("DELETE FROM rubric_assignment WHERE id_rubrik_assignment = ?");
        $deleteStmt->bind_param("i", $deleteId);
        $deleteStmt->execute();
        $deleteStmt->close();
    }

    // Catch the POST request from the previous page
    $selectedTerms = $_POST['terms'] ?? '';
    $selectedCourse = $_POST['course'] ?? '';

    $terms = '';
    $course = '';

// Check if terms and course are set in the URL
    if (isset($_GET['terms'])) {
        $selectedTerms = $_GET['terms'];
    }

    if (isset($_GET['course'])) {
        $selectedCourse = $_GET['course'];
    }

    $stmt = $conn->prepare("SELECT course_name FROM course WHERE course_code = ?");
    $stmt->bind_param("s", $selectedCourse); // Binding the course code as a string
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $row = $result->fetch_assoc();
        $courseName = $row['course_name']; // Fetch the course name
    } else {
        $courseName = 'Course not found'; // Handle case where no course is found
    }

    // Prepare the SQL query to fetch data from rubric_uts based on the selected term and course
    $sql = "SELECT id_rubrik_assignment, Question, SUB_CLO, R_Weight, Q_Weight FROM rubric_assignment WHERE Terms = ? AND Course = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ss", $selectedTerms, $selectedCourse);
    $stmt->execute();
    $result = $stmt->get_result();
?>

<!DOCTYPE html>
<html lang="en">
<head>  
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ELO Submission</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../../css/styles.css">

</head>
<body>
    <!-- Header Section -->
    <div class="container-fluid bg-light mb-4">
        <div class="row">
            <div class="col text-center header-container">
                <img id="menuButton" src="../../assets/menu_bar.png" alt="Menu" class="blackmagic-menu">
                <h2 class="header-title py-3">MyClass</h2>
            </div>
        </div>
    </div>

    <!-- Menu Overlay -->
    <div id="menuOverlay" class="overlay">
        <div class="menu">
            <h3>Menu</h3>
            <ul>
                <li><a href="../index_dashboard.php">Dashboard</a></li>
                <li id="menuItemUpload">
                    <a href="#">Halaman<br>Upload</a> <!-- No actual link -->
                </li>
                <li><a href="../terms_and_course.php">View Nilai</a></li>
                <li><a href="#">Item 4</a></li> 
            </ul>
        </div>
    </div>
        <div id="centerBox" class="center-box">
        <div class="box-content">
            <h2>Select an Action</h2>
            <button class="btn btn-primary mb-2" id="btnLec">Upload LEC</button>
            <button class="btn btn-secondary" id="btnLab">Upload LAB</button>
        </div>
    </div>


    <!-- Display Selected Term and Course -->
    <div class="container mt-4">
        <h3>Selected Term: <?php echo htmlspecialchars($selectedTerms); ?></h3>
        <h3>Course: <?php echo htmlspecialchars($selectedCourse); ?> - <?php echo htmlspecialchars($courseName); ?></h3>
    </div>

    <!-- Add Button -->
    <div class="container mt-4">
        <!-- Add Button Form -->
        <form action="rubric_asg_add.php" method="post"> <!-- Change 'add_record.php' to your actual add processing page -->
            <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerms); ?>">
            <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourse); ?>">
            <button type="submit" class="btn btn-success">Add</button>
        </form>
    </div>

    <!-- Bootstrap Table -->
    <div class="container mt-4">
        <form action="view_rubric_asg_table.php" method="post"> <!-- Change 'next_page.php' to your actual next page -->
        <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerms); ?>">
        <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourse); ?>">
        <!-- Include any other form elements or buttons here -->
    </form>
        <table class="table table-bordered table-striped">
            <thead>
                <tr>
                    <th>Question</th>
                    <th>SUB_CLO</th>
                    <th>R_Weight</th>
                    <th>Q_Weight</th>
                    <th>Actions</th> <!-- Extra column for actions -->

                </tr>
            </thead>
                <tbody>
                <?php 
                $index = 1; // Initialize index for auto-increment
                while ($row = $result->fetch_assoc()): ?>
                    <tr>

                        <td><?php echo htmlspecialchars($row['Question']); ?></td>
                        <td><?php echo htmlspecialchars($row['SUB_CLO']); ?></td>
                        <td><?php echo htmlspecialchars($row['R_Weight']); ?></td>
                        <td><?php echo htmlspecialchars($row['Q_Weight']); ?></td>
                        <td>
                            <form method="POST" action="update_rubric_asg.php" style="display:inline;">
                                <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerms); ?>">
                                <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourse); ?>">
                                <input type="hidden" name="rubric_assignment_id" value="<?php echo htmlspecialchars($row['id_rubrik_assignment']); ?>">
                                <button type="submit" name="action" value="update" class="btn btn-warning btn-sm">Update</button>
                                
                            </form>
                            <form method="POST" action="view_rubric_asg_table.php" style="display:inline;">
                                <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerms); ?>">
                                <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourse); ?>">
                                <input type="hidden" name="delete_id" value="<?php echo htmlspecialchars($row['id_rubrik_assignment']); ?>">
                                <button type="submit" name="action" value="delete" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this record?');">Delete</button>
                            </form>
                        </td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>
    </div>





    <?php
        // Close the database connection
        $stmt->close();
        $conn->close();
    ?>

        <div class="container mt-4">
        <form method="POST" action="../c_and_t_menu.php" style="display:inline;">
            <input type="hidden" name="terms" value="<?php echo htmlspecialchars($selectedTerms); ?>">
            <input type="hidden" name="course" value="<?php echo htmlspecialchars($selectedCourse); ?>">
            <button type="submit" class="btn btn-primary">Back</button>
        </form>
    </div>

    <script src="../../js/overlay_menu_box.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.10.2/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.min.js"></script>
</body>
</html>
