<?php
include '../../../database_connection.php';

// Establish a database connection
$conn = new mysqli($servername, $username, $password, $dbname);

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Retrieve data from the previous page (terms and course)
$receivedTerms = $_POST['terms'] ?? null;
$receivedCourse = $_POST['course'] ?? null;
$rubricAssignmentId = $_POST['rubric_assignment_id'] ?? null;

// Fetch the rubric data based on the received ID
$rubricData = null;

if ($rubricAssignmentId) {
    $stmt = $conn->prepare("SELECT * FROM rubric_assignment_lab WHERE id_rubrik_assignment = ?");
    $stmt->bind_param("i", $rubricAssignmentId);
    $stmt->execute();
    $result = $stmt->get_result();
    $rubricData = $result->fetch_assoc();
    $stmt->close();
}

// Fetch SUB_CLO data for the dropdown (from elo table)
$subCloOptions = [];
if ($receivedCourse && $receivedTerms) {
    $stmt = $conn->prepare("SELECT SUB_CLO FROM elo WHERE Course = ? AND Terms = ?");
    $stmt->bind_param("ss", $receivedCourse, $receivedTerms);
    $stmt->execute();
    $result = $stmt->get_result();
    while ($row = $result->fetch_assoc()) {
        $subCloOptions[] = $row['SUB_CLO']; // Fetch all SUB_CLO values
    }
    $stmt->close();
}

// Fetch column names and data from uts_scores table
$totalIncludedColumns = 0;  // Initialize counter for included columns
$columnSummary = ''; // Initialize variable to store summary output
$questionOptionsCount = 0; // To count the number of included columns for the Question dropdown
if ($receivedCourse && $receivedTerms) {
    $stmt = $conn->prepare("SELECT * FROM assignment_lab_scores WHERE course_code = ? AND terms = ?");
    $stmt->bind_param("ss", $receivedCourse, $receivedTerms);
    $stmt->execute();
    $result = $stmt->get_result();

    // Process if data exists
    if ($result->num_rows > 0) {
        $rows = $result->fetch_all(MYSQLI_ASSOC);
        $columnNames = array_keys($rows[0]); // Get column names

        // Iterate through each column (starting from index 4)
        for ($i = 4; $i < count($columnNames); $i++) {
            $currentColumnSum = 0;

            // Sum up the values in the current column
            foreach ($rows as $row) {
                $columnValue = $row[$columnNames[$i]];
                if (is_numeric($columnValue)) {
                    $currentColumnSum += $columnValue;
                }
            }

            // Check if the sum meets the inclusion criteria
            if ($currentColumnSum >= 1) {
                $totalIncludedColumns++;
                $questionOptionsCount++;
                // $columnSummary .= "<p>Column " . ($i + 1) . " - Sum: $currentColumnSum (Included)</p>";
            } else {
                // $columnSummary .= "<p>Column " . ($i + 1) . " - Sum: $currentColumnSum (Excluded)</p>";
            }
        }

        // Display total counts
        // $columnSummary .= "<h4>Total Included Columns: $totalIncludedColumns</h4>";
        // $columnSummary .= "<h4>Total Excluded Columns: " . (count($columnNames) - $totalIncludedColumns) . "</h4>";
    } else {
        $columnSummary .= "<p>No Score found in assignment scores lab. Please upload Score first</p>";
    }
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Rubric assignment</title>
    <link href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
<script>
        // Automatically calculate R_weight based on Q_weight
        function calculateRWeight() {
            var qWeight = document.getElementById('q_weight').value;
            var rWeightField = document.getElementById('r_weight');
            if (!isNaN(qWeight) && qWeight !== '') {
                rWeightField.value = (qWeight * 0.30).toFixed(2); // Reverse calculation
            }
        }
    </script>
</head>
<body>
    <div class="container mt-5">
        <h2>Edit Rubric assignment</h2>
        <form action="save_data_asg_lab.php" method="POST" class="row g-3">
            <!-- Hidden field to keep rubric_uts_id -->
            <input type="hidden" name="rubric_assignment_id" value="<?php echo htmlspecialchars($rubricAssignmentId); ?>">

            <div class="col-md-4">
                <label for="terms" class="form-label">Terms</label>
                <input type="text" class="form-control" id="terms" name="terms" value="<?php echo htmlspecialchars($receivedTerms); ?>" readonly>
            </div>
            <div class="col-md-4">
                <label for="course" class="form-label">Course</label>
                <input type="text" class="form-control" id="course" name="course" value="<?php echo htmlspecialchars($receivedCourse); ?>" readonly>
            </div>
            <div class="col-md-4">
                <label for="question" class="form-label">Assignment</label>
                <select name="question" id="question" class="form-control">
                    <option value="">--Select Assignment--</option>
                    <?php for ($i = 1; $i <= $questionOptionsCount; $i++) : ?>
                        <option value="<?php echo $i; ?>"><?php echo $i; ?></option>
                    <?php endfor; ?>
                </select>
            </div>
            <div class="col-md-4">
                <label for="sub_clo" class="form-label">SUB_CLO</label>
                <select name="sub_clo" id="sub_clo" class="form-control">
                    <option value="">--Select SUB_CLO--</option>
                    <?php foreach ($subCloOptions as $subClo) : ?>
                        <option value="<?php echo htmlspecialchars($subClo); ?>" <?php if ($subClo == $rubricData['SUB_CLO']) echo 'selected'; ?>>
                            <?php echo htmlspecialchars($subClo); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-4">
                <label for="q_weight" class="form-label">Q Weight</label>
                <input type="number" class="form-control" id="q_weight" name="q_weight" value="<?php echo htmlspecialchars($rubricData['Q_weight']); ?>" oninput="calculateRWeight()">
            </div>
            <div class="col-md-4">
                <label for="r_weight" class="form-label">R Weight</label>
                <input type="number" class="form-control" id="r_weight" name="r_weight" value="<?php echo htmlspecialchars($rubricData['R_Weight']); ?>" readonly>
            </div>
            <div class="col-12">
                <button type="submit" name="save_changes" class="btn btn-primary">Save Changes</button>
            </div>
        </form>

        <!-- Display the column summary -->
        <div class="mt-5"><!-- 
            <h3>Column Summary from assignment_scores</h3> -->
            <?php echo $columnSummary; ?>
        </div>

  
</body>
</html>
