<?php
// Enable error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include the database connection file
include '../database_connection.php';  // Adjust the path if necessary

// Ensure JSON header for proper response
header('Content-Type: application/json');

try {
    // Capture the incoming JSON data from the request body
    $jsonData = file_get_contents('php://input');
    $data = json_decode($jsonData, true);

    if (!$data || !isset($data['rows'])) {
        throw new Exception('No data provided or invalid JSON format.');
    }

    // Prepare database connection
    $conn = new mysqli($servername, $username, $password, $dbname);

    if ($conn->connect_error) {
        throw new Exception('Database connection failed: ' . $conn->connect_error);
    }

    // Extract course code from row 4, column B
    $courseCode = isset($data['rows'][3][1]) ? $conn->real_escape_string($data['rows'][3][1]) : null;

    if (!$courseCode) {
        throw new Exception('Course code not found in the expected cell (Row 4, Column B).');
    }

    // Iterate over the rows starting from row 7 (index 6)
    for ($index = 7; $index < count($data['rows']); $index++) {
        $row = $data['rows'][$index];

        // Ensure the row has data and NIM is not empty
        if (empty($row[0]) || empty($courseCode)) {
            // Skip rows without valid NIM or Course Code
            continue;
        }

        // Extract the data (adjust according to the columns in your table)
        // Ignore the "Class of" column at index 3
        $nim = $conn->real_escape_string($row[0]);
        $name = isset($row[1]) ? $conn->real_escape_string($row[1]) : '';
        $terms = isset($data['rows'][2][1]) ? $conn->real_escape_string($data['rows'][2][1]) : null;  // If name is missing, set it as an empty string
        $q1 = isset($row[4]) ? $conn->real_escape_string($row[4]) : '0';    // Skip index 3, move to index 4
        $q2 = isset($row[5]) ? $conn->real_escape_string($row[5]) : '0';
        $q3 = isset($row[6]) ? $conn->real_escape_string($row[6]) : '0';
        $q4 = isset($row[7]) ? $conn->real_escape_string($row[7]) : '0';
        $q5 = isset($row[8]) ? $conn->real_escape_string($row[8]) : '0';
        $q6 = isset($row[9]) ? $conn->real_escape_string($row[9]) : '0';
        $q7 = isset($row[10]) ? $conn->real_escape_string($row[10]) : '0';
        $q8 = isset($row[11]) ? $conn->real_escape_string($row[11]) : '0';
        $q9 = isset($row[12]) ? $conn->real_escape_string($row[12]) : '0';
        $q10 = isset($row[13]) ? $conn->real_escape_string($row[13]) : '0';

        // Insert or update query for the uts_scores table
        $sql = "INSERT INTO uts_lab_scores(NIM, Name, terms, Course_Code, `Question 1`, `Question 2`, `Question 3`, `Question 4`, `Question 5`, `Question 6`, `Question 7`, `Question 8`, `Question 9`, `Question 10`)
                VALUES ('$nim', '$name','$terms', '$courseCode', '$q1', '$q2', '$q3', '$q4', '$q5', '$q6', '$q7', '$q8', '$q9', '$q10')
                ON DUPLICATE KEY UPDATE
                Name = '$name', Course_Code = '$courseCode', `Question 1` = '$q1', `Question 2` = '$q2', `Question 3` = '$q3', `Question 4` = '$q4', `Question 5` = '$q5', 
                `Question 6` = '$q6', `Question 7` = '$q7', `Question 8` = '$q8', `Question 9` = '$q9', `Question 10` = '$q10'";

        if (!$conn->query($sql)) {
            throw new Exception('Database query failed: ' . $conn->error);
        }
    }

    // Success response
    echo json_encode([
        'status' => 'success',
        'message' => 'Data uploaded successfully.'
    ]);

} catch (Exception $e) {
    // Error response in JSON format
    echo json_encode([
        'status' => 'error',
        'message' => $e->getMessage()
    ]);
}
