<?php
include '../basic_page.html';
include '../database_connection.php';

// Establish database connection
$conn = new mysqli($servername, $username, $password, $dbname);
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Get selected term and course
$selectedTerm = isset($_POST['terms']) ? $_POST['terms'] : 'Unknown Term';
$selectedCourse = isset($_POST['course']) ? $_POST['course'] : 'Unknown Course';

// Function to fetch non-zero columns from a given score table
function getNonZeroColumns($conn, $table, $selectedTerm, $selectedCourse) {
    $columns = [];
    $query = "SELECT * FROM $table WHERE Terms = ? AND Course_code = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("ss", $selectedTerm, $selectedCourse);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        // Fetch column names dynamically
        $row = $result->fetch_assoc();
        foreach ($row as $key => $value) {
            // Exclude NIM column from the checks
            if ($key === 'NIM') {
                continue;
            }

            // Check if the column has all zeros in the entire table
            $zeroCheckQuery = "SELECT COUNT(*) as count FROM $table WHERE `$key` = 0 AND Terms = ? AND Course_code = ?";
            $zeroStmt = $conn->prepare($zeroCheckQuery);
            $zeroStmt->bind_param("ss", $selectedTerm, $selectedCourse);
            $zeroStmt->execute();
            $zeroResult = $zeroStmt->get_result()->fetch_assoc();

            // If not all values are zero, add to column names
            if ($zeroResult['count'] < $result->num_rows) {
                $columns[] = $key; // Add the column to the list if not all zeros
            }
        }
    }
    return $columns;
}

// Fetch columns from each scores table
$utsColumns = getNonZeroColumns($conn, 'uts_scores', $selectedTerm, $selectedCourse);
$uasColumns = getNonZeroColumns($conn, 'uas_scores', $selectedTerm, $selectedCourse);
$assignmentColumns = getNonZeroColumns($conn, 'assignment_scores', $selectedTerm, $selectedCourse);

// Fetch columns from lab scores tables
$utsLabColumns = getNonZeroColumns($conn, 'uts_lab_scores', $selectedTerm, $selectedCourse);
$uasLabColumns = getNonZeroColumns($conn, 'uas_lab_scores', $selectedTerm, $selectedCourse);
$assignmentLabColumns = getNonZeroColumns($conn, 'assignment_lab_scores', $selectedTerm, $selectedCourse);

// Count the number of rows in each rubric table
$rubricCounts = [];
$rubricTables = [
    'rubric_uts' => $utsColumns,
    'rubric_uas' => $uasColumns,
    'rubric_assignment' => $assignmentColumns,
    'rubric_uts_lab' => $utsLabColumns,
    'rubric_uas_lab' => $uasLabColumns,
    'rubric_assignment_lab' => $assignmentLabColumns
];

foreach ($rubricTables as $rubric => $columns) {
    $rubricQuery = "SELECT COUNT(*) as count FROM $rubric WHERE Terms = ? AND Course = ?";
    $rubricStmt = $conn->prepare($rubricQuery);
    $rubricStmt->bind_param("ss", $selectedTerm, $selectedCourse);
    $rubricStmt->execute();
    $rubricResult = $rubricStmt->get_result()->fetch_assoc();
    $rubricCounts[$rubric] = ['count' => $rubricResult['count'], 'columns' => $columns];
}

// Check if the number of columns matches the number of rows in each rubric table
foreach ($rubricCounts as $rubric => $data) {
    $columnCount = count($data['columns']);
    if ($data['count'] == $columnCount) {
        echo "The number of columns in the $rubric table matches the corresponding scores columns.<br>";
    } else {
        echo "The number of columns in the $rubric table does not match the corresponding scores columns.<br>";
    }
}

// Display the columns and counts for debugging purposes
echo "<h3>Selected Term: $selectedTerm</h3>";
echo "<h3>Selected Course: $selectedCourse</h3>";

echo "<h3>Columns from uts_scores (excluding all-zero columns):</h3>";
echo "<ul>";
foreach ($utsColumns as $columnName) {
    echo "<li>$columnName</li>";
}
echo "</ul>";

echo "<h3>Columns from uas_scores (excluding all-zero columns):</h3>";
echo "<ul>";
foreach ($uasColumns as $columnName) {
    echo "<li>$columnName</li>";
}
echo "</ul>";

echo "<h3>Columns from assignment_scores (excluding all-zero columns):</h3>";
echo "<ul>";
foreach ($assignmentColumns as $columnName) {
    echo "<li>$columnName</li>";
}
echo "</ul>";

// Display lab columns
echo "<h3>Columns from uts_lab_scores (excluding all-zero columns):</h3>";
echo "<ul>";
foreach ($utsLabColumns as $columnName) {
    echo "<li>$columnName</li>";
}
echo "</ul>";

echo "<h3>Columns from uas_lab_scores (excluding all-zero columns):</h3>";
echo "<ul>";
foreach ($uasLabColumns as $columnName) {
    echo "<li>$columnName</li>";
}
echo "</ul>";

echo "<h3>Columns from assignment_lab_scores (excluding all-zero columns):</h3>";
echo "<ul>";
foreach ($assignmentLabColumns as $columnName) {
    echo "<li>$columnName</li>";
}
echo "</ul>";

// Close the database connection
$conn->close();
?>
