<?php
include '../database_connection.php';

// Establish database connection
$conn = new mysqli($servername, $username, $password, $dbname);
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Step 1: Retrieve selected term and course for filtering
$selectedTerm = isset($_POST['terms']) ? $_POST['terms'] : 'Unknown Term';
$selectedCourse = isset($_POST['course']) ? $conn->real_escape_string($_POST['course']) : 'Unknown Course';

// Step 2: Fetch the sorted rubric_uts
$rubric_query = "SELECT * FROM rubric_uts WHERE Course = '$selectedCourse' AND Terms = '$selectedTerm' ORDER BY Question ASC";
$rubric_result = $conn->query($rubric_query);

// Step 3: Fetch the corresponding uts_scores for all students
$scores_query = "SELECT * FROM uts_scores WHERE Course_Code = '$selectedCourse' AND Terms = '$selectedTerm'";
$scores_result = $conn->query($scores_query);

// Initialize an array to hold the results
$final_scores = [];

// Initialize variables for total accumulation and student count
$sum_total_scores = 0;
$student_count = 0;

// Check if both queries returned results
if ($rubric_result->num_rows > 0 && $scores_result->num_rows > 0) {
    // Fetch the rubric data into an array for easier access
    $rubric_data = [];
    while ($row = $rubric_result->fetch_assoc()) {
        $rubric_data[] = $row;
    }

    // Prepare to collect student names and total scores for the graph
    $student_names = [];
    $total_scores = [];

    // Step 6: Process each student's scores
    while ($scores_data = $scores_result->fetch_assoc()) {
        // Extract NIM and Name for the current student
        $nim = htmlspecialchars($scores_data['NIM']);
        $name = htmlspecialchars($scores_data['Name']); // Assuming there's a 'Name' column

        // Initialize a total score
        $total_score = 0; // Initialize total score

        // Calculate the weighted scores for each question
        foreach ($rubric_data as $rubric_row) {
            // Extract the relevant columns
            $question_number = $rubric_row['Question'];
            $q_weight = $rubric_row['Q_weight'];
            $r_weight = $rubric_row['R_Weight'];

            // Check if the score column exists in scores_data
            $score_column = "Question $question_number"; // Assuming the column names follow the pattern "Question X"
            if (isset($scores_data[$score_column])) {
                $score = $scores_data[$score_column];

                // Calculate the score multiplied by Q_weight
                $weighted_score = $score; // Adjust as necessary based on weighting
                $total_score += $weighted_score; // Accumulate total score
            }
        }

        // Accumulate total score for average calculation
        $sum_total_scores += $total_score;
        $student_count++;

        // Store names and total scores for the graph
        $student_names[] = $name; 
        $total_scores[] = $total_score; 
    }

    // Close the database connection
    $conn->close();

    // Combine student names and total scores into an associative array
    $combined = array_combine($student_names, $total_scores);

    // Sort the combined array based on scores (values) in descending order
    arsort($combined);

    // Separate the sorted names and scores back into two arrays
    $sorted_student_names = array_keys($combined);
    $sorted_total_scores = array_values($combined);

    // Calculate the average score
    $average_score = $student_count > 0 ? $sum_total_scores / $student_count : 0;

    // Include Chart.js
    echo '<div style="margin-bottom: 10px; font-size: 18px; font-weight: bold; color: skyblue;">Average Score: ' . round($average_score, 2) . '</div>'; // Change color to sky blue
    echo '<canvas id="myBarChart" width="400" height="200" style="background-color: white;"></canvas>'; // White background for canvas
    echo '<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>';
    echo '<script>
        const ctx = document.getElementById("myBarChart").getContext("2d");
        const myBarChart = new Chart(ctx, {
            type: "bar",
            data: {
                labels: ' . json_encode($sorted_student_names) . ',
                datasets: [{
                    label: "Total Scores",
                    data: ' . json_encode($sorted_total_scores) . ',
                    backgroundColor: "rgba(75, 192, 192, 0.2)",
                    borderColor: "rgba(75, 192, 192, 1)",
                    borderWidth: 1
                }]
            },
            options: {
                scales: {
                    y: {
                        beginAtZero: true,
                        ticks: {
                            stepSize: 20 // Set the step size for y-axis
                        }
                    },
                    x: {
                        grid: {
                            color: "rgba(0, 0, 0, 0.1)" // Optional: lighter grid lines
                        }
                    },
                    y: {
                        grid: {
                            color: "rgba(0, 0, 0, 0.1)" // Optional: lighter grid lines
                        }
                    }
                }
            }
        });
    </script>';
} else {
    echo "<p>No records found for the selected term and course.</p>";
}
?>
