<?php
include '../database_connection.php';

// Establish database connection
$conn = new mysqli($servername, $username, $password, $dbname);
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Retrieve selected term and course for filtering
$selectedTerm = isset($_POST['terms']) ? $_POST['terms'] : 'Unknown Term';
$selectedCourse = isset($_POST['course']) ? $conn->real_escape_string($_POST['course']) : 'Unknown Course';

// Fetch the sorted rubric_assignment
$rubric_query = "SELECT * FROM rubric_assignment WHERE Course = '$selectedCourse' AND Terms = '$selectedTerm' ORDER BY Question ASC";
$rubric_result = $conn->query($rubric_query);

// Fetch the corresponding assignment_scores for all students
$scores_query = "SELECT * FROM assignment_scores WHERE Course_Code = '$selectedCourse' AND Terms = '$selectedTerm'";
$scores_result = $conn->query($scores_query);

// Initialize variables
$rubric_data = [];

// Check if both queries returned results
if ($rubric_result->num_rows > 0 && $scores_result->num_rows > 0) {
    while ($row = $rubric_result->fetch_assoc()) {
        $rubric_data[] = $row;
    }

    // Display Rubric Table
    echo '<div class="weights-table-container">';
    echo '<h3>Weighted assignment Scores for ' . htmlspecialchars($selectedCourse) . ' - ' . htmlspecialchars($selectedTerm) . '</h3>';
    echo '<table id="weightsTable" class="table table-striped table-bordered">';
    echo '<thead><tr><th>Assignment</th><th>R Weight (%)</th><th>Q Weight (%)</th></tr></thead><tbody>';

    foreach ($rubric_data as $rubric_row) {
        echo '<tr>';
        echo '<td>Assignment ' . htmlspecialchars($rubric_row['Question']) . '</td>';
        echo '<td>' . htmlspecialchars($rubric_row['R_Weight']) . '</td>';
        echo '<td>' . htmlspecialchars($rubric_row['Q_weight']) . '</td>';
        echo '</tr>';
    }

    echo '</tbody></table></div>';

    // Prepare data for the bar chart
    $student_names = [];
    $average_scores = [];
    $score_names_map = [];
    while ($scores_data = $scores_result->fetch_assoc()) {
        $nim = htmlspecialchars($scores_data['NIM']);
        $name = htmlspecialchars($scores_data['Name']);
        $total_score = 0;
        $assignment_count = 0;

        // Calculate the average score
        foreach ($rubric_data as $rubric_row) {
            $Assignment_number = $rubric_row['Question'];
            $score_column = "Assignment $Assignment_number";
            if (isset($scores_data[$score_column])) {
                $total_score += $scores_data[$score_column];
                $assignment_count++;
            }
        }

        // Calculate average score
        $average_score = $assignment_count > 0 ? $total_score / $assignment_count : 0;

        $student_names[] = $name;
        $average_scores[] = $average_score;

        if (!isset($score_names_map[$average_score])) {
            $score_names_map[$average_score] = [];
        }
        $score_names_map[$average_score][] = $name;
    }

    // Sort the average scores from highest to lowest
    $combined = array_combine($average_scores, $student_names);
    arsort($combined);
    $sorted_student_names = array_values($combined);
    $sorted_average_scores = array_keys($combined);

    // Display the average score and chart
    $baseHeight = 200; // Base height in pixels
    $entryHeight = 10; // Additional height per entry in pixels
    $canvasHeight = $baseHeight + (count($sorted_student_names) * $entryHeight); // Total height calculation

    echo '<canvas id="myBarChart3" width="800" height="' . $canvasHeight . '" style="background-color: white;"></canvas>'; // Dynamic height
    echo '<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>';
    echo '<script>
        const ctx3 = document.getElementById("myBarChart3").getContext("2d");
        const scoreNamesMap3 = ' . json_encode($score_names_map) . ';
        const myBarChart3 = new Chart(ctx3, {
            type: "bar",
            data: {
                labels: Object.keys(scoreNamesMap3).sort((a, b) => b - a), // Sort labels from high to low score
                datasets: [{
                    label: "Student Count",
                    data: Object.keys(scoreNamesMap3).sort((a, b) => b - a).map(score => scoreNamesMap3[score].length),
                    backgroundColor: "rgba(75, 192, 192, 0.8)",
                    borderColor: "rgba(75, 192, 192, 1)",
                    borderWidth: 1
                }]
            },
            options: {
                indexAxis: "y",
                onClick: (e) => {
                    const activePoints = myBarChart3.getElementsAtEventForMode(e, "nearest", { intersect: true }, true);
                    if (activePoints.length > 0) {
                        const score = myBarChart3.data.labels[activePoints[0].index];
                        const namesToFilter = scoreNamesMap3[score];
                        const table = $("#assignmentScoresTable").DataTable();
                        table.search("").draw(); // Clear previous search filter
                        table.rows().every(function() {
                            const rowName = this.data()[1];
                            if (!namesToFilter.includes(rowName)) {
                                this.nodes().to$().hide();
                            } else {
                                this.nodes().to$().show();
                            }
                        });
                    }
                },
                plugins: {
                    tooltip: {
                        callbacks: {
                            label: function(tooltipItem) {
                                const score = tooltipItem.label;
                            }
                        }
                    }
                },
                scales: {
                    x: {
                        beginAtZero: true,
                        ticks: {
                            stepSize: 1
                        }
                    }
                }
            }
        });
    </script>';

    // Display Scores Table
    echo '<div class="table-container">';
    echo '<table id="assignmentScoresTable" class="table table-striped table-bordered" style="width:100%">';
    echo '<thead><tr><th>NIM</th><th>Name</th>';

    foreach ($rubric_data as $rubric_row) {
        echo '<th>Assignment ' . htmlspecialchars($rubric_row['Question']) . '</th>';
    }
    echo '<th>Average</th></tr></thead><tbody>';

    $scores_result->data_seek(0); // Reset scores result set to beginning
    while ($scores_data = $scores_result->fetch_assoc()) {
        $nim = htmlspecialchars($scores_data['NIM']);
        $name = htmlspecialchars($scores_data['Name']);
        $total_score = 0;
        $assignment_count = 0;

        echo '<tr>';
        echo '<td>' . $nim . '</td>';
        echo '<td>' . $name . '</td>';

        foreach ($rubric_data as $rubric_row) {
            $Assignment_number = $rubric_row['Question'];
            $score_column = "Assignment $Assignment_number";
            $score = isset($scores_data[$score_column]) ? $scores_data[$score_column] : 0;
            $total_score += $score;
            $assignment_count++;
            echo '<td>' . number_format($score, 2) . '</td>';
        }

        // Calculate the average score
        $average_score = $assignment_count > 0 ? $total_score / $assignment_count : 0;
        echo '<td>' . number_format($average_score, 2) . '</td>';
        echo '</tr>';
    }

    echo '</tbody></table></div>';
} else {
    echo "<p>No records found for the selected term and course.</p>";
}

$conn->close();
?>


<link rel="stylesheet" href="https://cdn.datatables.net/1.11.5/css/jquery.dataTables.min.css">
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>

<script>
$(document).ready(function() {
    const table = $('#assignmentScoresTable').DataTable({
        pageLength: 50 // Set the default number of entries to show
    });

    // Reset table on a new search input
    $('#assignmentScoresTable_filter input').on("input", function() {
        table.rows().every(function() {
            this.nodes().to$().show();
        });
    });
});
</script>

<style>
.weights-table-container, .table-container {
    padding-left: 30px;
    padding-right: 30px;
}
.weights-table-container table, .table-container table {
    width: auto;
    margin-bottom: 30px;
}
.dataTables_filter {
    margin: 20px 0;
}
.dataTables_filter input {
    margin-left: 10px;
}
</style>
