<?php
include '../database_connection.php';

// Establish database connection
$conn = new mysqli($servername, $username, $password, $dbname);
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Retrieve selected term and course for filtering
$selectedTerm = isset($_POST['terms']) ? $_POST['terms'] : 'Unknown Term';
$selectedCourse = isset($_POST['course']) ? $conn->real_escape_string($_POST['course']) : 'Unknown Course';

// Fetch the sorted rubric_uas
$rubric_query = "SELECT * FROM rubric_uas_lab WHERE Course = '$selectedCourse' AND Terms = '$selectedTerm' ORDER BY Question ASC";
$rubric_result = $conn->query($rubric_query);

// Fetch the corresponding uas_scores for all students
$scores_query = "SELECT * FROM uas_lab_scores WHERE Course_Code = '$selectedCourse' AND Terms = '$selectedTerm'";
$scores_result = $conn->query($scores_query);

// Initialize variables
$final_scores = [];
$sum_total_scores = 0;
$student_count = 0;
$rubric_data = [];

// Check if both queries returned results
if ($rubric_result->num_rows > 0 && $scores_result->num_rows > 0) {
    while ($row = $rubric_result->fetch_assoc()) {
        $rubric_data[] = $row;
    }

    // Display Rubric Table
    echo '<div class="weights-table-container">';
    echo '<h3>Weighted uas Scores for ' . htmlspecialchars($selectedCourse) . ' - ' . htmlspecialchars($selectedTerm) . '</h3>';
    echo '<table id="weightsTable" class="table table-striped table-bordered">';
    echo '<thead><tr><th>Question</th><th>R Weight (%)</th><th>Q Weight (%)</th></tr></thead><tbody>';

    foreach ($rubric_data as $rubric_row) {
        echo '<tr>';
        echo '<td>Question ' . htmlspecialchars($rubric_row['Question']) . '</td>';
        echo '<td>' . htmlspecialchars($rubric_row['R_Weight']) . '</td>';
        echo '<td>' . htmlspecialchars($rubric_row['Q_weight']) . '</td>';
        echo '</tr>';
    }

    echo '</tbody></table></div>';

    // Prepare data for the bar chart
    $student_names = [];
    $total_scores = [];
    $score_names_map = [];
    while ($scores_data = $scores_result->fetch_assoc()) {
        $nim = htmlspecialchars($scores_data['NIM']);
        $name = htmlspecialchars($scores_data['Name']);
        $total_score = 0;

        foreach ($rubric_data as $rubric_row) {
            $question_number = $rubric_row['Question'];
            $score_column = "Question $question_number";
            if (isset($scores_data[$score_column])) {
                $total_score += $scores_data[$score_column];
            }
        }

        $student_names[] = $name;
        $total_scores[] = $total_score;
        $sum_total_scores += $total_score;
        $student_count++;
        
        if (!isset($score_names_map[$total_score])) {
            $score_names_map[$total_score] = [];
        }
        $score_names_map[$total_score][] = $name;
    }

    $average_score = $student_count > 0 ? $sum_total_scores / $student_count : 0;

    // Sort the bar chart data from highest to lowest
    $combined = array_combine($total_scores, $student_names);
    arsort($combined);
    $sorted_student_names = array_values($combined);
    $sorted_total_scores = array_keys($combined);

    // Display the average score and chart
    $baseHeight = 200; // Base height in pixels
    $entryHeight = 10; // Additional height per entry in pixels
    $canvasHeight = $baseHeight + (count($sorted_student_names) * $entryHeight); // Total height calculation

    echo '<canvas id="myBarChart5" width="800" height="' . $canvasHeight . '" style="background-color: white;"></canvas>'; // Dynamic height
    echo '<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>';
    echo '<script>
        const ctx5 = document.getElementById("myBarChart5").getContext("2d");
        const scoreNamesMap5 = ' . json_encode($score_names_map) . ';
        const myBarChart5 = new Chart(ctx5, {
            type: "bar",
            data: {
                labels: Object.keys(scoreNamesMap5).sort((a, b) => b - a), // Sort labels from high to low score
                datasets: [{
                    label: "Student Count",
                    data: Object.keys(scoreNamesMap5).sort((a, b) => b - a).map(score => scoreNamesMap5[score].length),
                    backgroundColor: "rgba(75, 192, 192, 0.8)",
                    borderColor: "rgba(75, 192, 192, 1)",
                    borderWidth: 1
                }]
            },
            options: {
                indexAxis: "y",
                onClick: (e) => {
                    const activePoints = myBarChart5.getElementsAtEventForMode(e, "nearest", { intersect: true }, true);
                    if (activePoints.length > 0) {
                        const score = myBarChart5.data.labels[activePoints[0].index];
                        const namesToFilter = scoreNamesMap5[score];
                        const table = $("#uasScoresTable2").DataTable();
                        table.search("").draw(); // Clear previous search filter
                        table.rows().every(function() {
                            const rowName = this.data()[1];
                            if (!namesToFilter.includes(rowName)) {
                                this.nodes().to$().hide();
                            } else {
                                this.nodes().to$().show();
                            }
                        });
                    }
                },
                plugins: {
                    tooltip: {
                        callbacks: {
                            label: function(tooltipItem) {
                                const score = tooltipItem.label;
                                // const names = scoreNamesMap5[score] || [];
                                // return "Names: \n" + names.join(", ");
                            }
                        }
                    }
                },
                scales: {
                    x: {
                        beginAtZero: true,
                        ticks: {
                            stepSize: 1
                        }
                    }
                }
            }
        });
    </script>';

    // Display Scores Table
    echo '<div class="table-container">';
    echo '<table id="uasScoresTable2" class="table table-striped table-bordered" style="width:100%">';
    echo '<thead><tr><th>NIM</th><th>Name</th>';

    foreach ($rubric_data as $rubric_row) {
        echo '<th>Question ' . htmlspecialchars($rubric_row['Question']) . '</th>';
    }
    echo '<th>Total</th></tr></thead><tbody>';

    $scores_result->data_seek(0); // Reset scores result set to beginning
    while ($scores_data = $scores_result->fetch_assoc()) {
        $nim = htmlspecialchars($scores_data['NIM']);
        $name = htmlspecialchars($scores_data['Name']);
        $total_score = 0;

        echo '<tr>';
        echo '<td>' . $nim . '</td>';
        echo '<td>' . $name . '</td>';

        foreach ($rubric_data as $rubric_row) {
            $question_number = $rubric_row['Question'];
            $score_column = "Question $question_number";
            $score = isset($scores_data[$score_column]) ? $scores_data[$score_column] : 0;
            $total_score += $score;
            echo '<td>' . number_format($score, 2) . '</td>';
        }

        echo '<td>' . number_format($total_score, 2) . '</td>';
        echo '</tr>';
    }

    echo '</tbody></table></div>';
} else {
    echo "<p>No records found for the selected term and course.</p>";
}

$conn->close();
?>

<link rel="stylesheet" href="https://cdn.datatables.net/1.11.5/css/jquery.dataTables.min.css">
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>

<script>
$(document).ready(function() {
    const table = $('#uasScoresTable2').DataTable({
        pageLength: 50 // Set the default number of entries to show
    });

    // Reset table on a new search input
    $('#uasScoresTable2_filter input').on("input", function() {
        table.rows().every(function() {
            this.nodes().to$().show();
        });
    });
});
</script>

<style>
.weights-table-container, .table-container {
    padding-left: 30px;
    padding-right: 30px;
}
.weights-table-container table, .table-container table {
    width: auto;
    margin-bottom: 30px;
}
.dataTables_filter {
    margin: 20px 0;
}
.dataTables_filter input {
    margin-left: 10px;
}
</style>
